# Reference

<!-- DO NOT EDIT: This document was generated by Puppet Strings -->

## Table of Contents

### Classes

#### Public Classes

* [`nginx`](#nginx): Manage NGINX

#### Private Classes

* `nginx::config`: Manage NGINX bootstrap and configuration
* `nginx::package`: Manage NGINX package installation
* `nginx::package::debian`: Manage NGINX package installation on debian based systems
* `nginx::package::redhat`: Manage NGINX package installation on RedHat based systems
* `nginx::params`: default settings and according to operating system
* `nginx::service`: Manage NGINX service management

### Defined types

* [`nginx::resource::geo`](#nginxresourcegeo): Create a new geo mapping entry for NGINX
* [`nginx::resource::location`](#nginxresourcelocation): Create a new location entry within a virtual host
* [`nginx::resource::mailhost`](#nginxresourcemailhost): Define a mailhost
* [`nginx::resource::map`](#nginxresourcemap): Create a new mapping entry for NGINX
* [`nginx::resource::server`](#nginxresourceserver): Create a virtual host
* [`nginx::resource::snippet`](#nginxresourcesnippet): Create a reusable config snippet that can be included by other resources
* [`nginx::resource::streamhost`](#nginxresourcestreamhost): Create a virtual steamhost
* [`nginx::resource::upstream`](#nginxresourceupstream): Create a new upstream proxy entry for NGINX
* [`nginx::resource::upstream::member`](#nginxresourceupstreammember): Create an upstream member inside the upstream block.

### Data types

* [`Nginx::DebugConnection`](#nginxdebugconnection)
* [`Nginx::ErrorLogSeverity`](#nginxerrorlogseverity)
* [`Nginx::Size`](#nginxsize)
* [`Nginx::Time`](#nginxtime)
* [`Nginx::UpstreamCustomParameters`](#nginxupstreamcustomparameters)
* [`Nginx::UpstreamDefaults`](#nginxupstreamdefaults)
* [`Nginx::UpstreamLeastTime`](#nginxupstreamleasttime)
* [`Nginx::UpstreamLeastTimeHttp`](#nginxupstreamleasttimehttp)
* [`Nginx::UpstreamLeastTimeStream`](#nginxupstreamleasttimestream)
* [`Nginx::UpstreamMember`](#nginxupstreammember)
* [`Nginx::UpstreamMemberDefaults`](#nginxupstreammemberdefaults)
* [`Nginx::UpstreamMemberServer`](#nginxupstreammemberserver)
* [`Nginx::UpstreamMembers`](#nginxupstreammembers)
* [`Nginx::UpstreamSticky`](#nginxupstreamsticky)
* [`Nginx::UpstreamStickyZone`](#nginxupstreamstickyzone)
* [`Nginx::UpstreamZone`](#nginxupstreamzone)

## Classes

### <a name="nginx"></a>`nginx`

Packaged NGINX
  - RHEL: EPEL or custom package
  - Debian/Ubuntu: Default Install or custom package
  - SuSE: Default Install or custom package

#### Examples

##### Use the sensible defaults

```puppet
include nginx
```

#### Parameters

The following parameters are available in the `nginx` class:

* [`include_modules_enabled`](#include_modules_enabled)
* [`passenger_package_name`](#passenger_package_name)
* [`nginx_version`](#nginx_version)
* [`debug_connections`](#debug_connections)
* [`service_config_check`](#service_config_check)
* [`service_config_check_command`](#service_config_check_command)
* [`reset_timedout_connection`](#reset_timedout_connection)
* [`client_body_temp_path`](#client_body_temp_path)
* [`confd_only`](#confd_only)
* [`confd_purge`](#confd_purge)
* [`conf_dir`](#conf_dir)
* [`daemon`](#daemon)
* [`daemon_user`](#daemon_user)
* [`daemon_group`](#daemon_group)
* [`dynamic_modules`](#dynamic_modules)
* [`global_owner`](#global_owner)
* [`global_group`](#global_group)
* [`global_mode`](#global_mode)
* [`limit_req_zone`](#limit_req_zone)
* [`log_dir`](#log_dir)
* [`log_user`](#log_user)
* [`log_group`](#log_group)
* [`log_mode`](#log_mode)
* [`http_access_log`](#http_access_log)
* [`http_format_log`](#http_format_log)
* [`nginx_error_log`](#nginx_error_log)
* [`nginx_error_log_severity`](#nginx_error_log_severity)
* [`pid`](#pid)
* [`proxy_temp_path`](#proxy_temp_path)
* [`root_group`](#root_group)
* [`run_dir`](#run_dir)
* [`sites_available_owner`](#sites_available_owner)
* [`sites_available_group`](#sites_available_group)
* [`sites_available_mode`](#sites_available_mode)
* [`super_user`](#super_user)
* [`temp_dir`](#temp_dir)
* [`server_purge`](#server_purge)
* [`conf_template`](#conf_template)
* [`fastcgi_conf_template`](#fastcgi_conf_template)
* [`uwsgi_params_template`](#uwsgi_params_template)
* [`absolute_redirect`](#absolute_redirect)
* [`accept_mutex`](#accept_mutex)
* [`accept_mutex_delay`](#accept_mutex_delay)
* [`client_body_buffer_size`](#client_body_buffer_size)
* [`client_max_body_size`](#client_max_body_size)
* [`client_body_timeout`](#client_body_timeout)
* [`send_timeout`](#send_timeout)
* [`lingering_timeout`](#lingering_timeout)
* [`lingering_close`](#lingering_close)
* [`lingering_time`](#lingering_time)
* [`etag`](#etag)
* [`events_use`](#events_use)
* [`fastcgi_cache_inactive`](#fastcgi_cache_inactive)
* [`fastcgi_cache_key`](#fastcgi_cache_key)
* [`fastcgi_cache_keys_zone`](#fastcgi_cache_keys_zone)
* [`fastcgi_cache_levels`](#fastcgi_cache_levels)
* [`fastcgi_cache_max_size`](#fastcgi_cache_max_size)
* [`fastcgi_cache_path`](#fastcgi_cache_path)
* [`fastcgi_cache_use_stale`](#fastcgi_cache_use_stale)
* [`gzip`](#gzip)
* [`gzip_buffers`](#gzip_buffers)
* [`gzip_comp_level`](#gzip_comp_level)
* [`gzip_disable`](#gzip_disable)
* [`gzip_min_length`](#gzip_min_length)
* [`gzip_http_version`](#gzip_http_version)
* [`gzip_proxied`](#gzip_proxied)
* [`gzip_types`](#gzip_types)
* [`gzip_vary`](#gzip_vary)
* [`gzip_static`](#gzip_static)
* [`http_cfg_prepend`](#http_cfg_prepend)
* [`http_cfg_append`](#http_cfg_append)
* [`http_raw_prepend`](#http_raw_prepend)
* [`http_raw_append`](#http_raw_append)
* [`http_tcp_nodelay`](#http_tcp_nodelay)
* [`http_tcp_nopush`](#http_tcp_nopush)
* [`keepalive_timeout`](#keepalive_timeout)
* [`keepalive_requests`](#keepalive_requests)
* [`log_format`](#log_format)
* [`mail`](#mail)
* [`mime_types_path`](#mime_types_path)
* [`stream`](#stream)
* [`multi_accept`](#multi_accept)
* [`names_hash_bucket_size`](#names_hash_bucket_size)
* [`names_hash_max_size`](#names_hash_max_size)
* [`nginx_cfg_prepend`](#nginx_cfg_prepend)
* [`proxy_buffers`](#proxy_buffers)
* [`proxy_buffer_size`](#proxy_buffer_size)
* [`proxy_cache_inactive`](#proxy_cache_inactive)
* [`proxy_cache_keys_zone`](#proxy_cache_keys_zone)
* [`proxy_cache_levels`](#proxy_cache_levels)
* [`proxy_cache_max_size`](#proxy_cache_max_size)
* [`proxy_cache_path`](#proxy_cache_path)
* [`proxy_cache_loader_files`](#proxy_cache_loader_files)
* [`proxy_cache_loader_sleep`](#proxy_cache_loader_sleep)
* [`proxy_cache_loader_threshold`](#proxy_cache_loader_threshold)
* [`proxy_use_temp_path`](#proxy_use_temp_path)
* [`proxy_connect_timeout`](#proxy_connect_timeout)
* [`proxy_headers_hash_bucket_size`](#proxy_headers_hash_bucket_size)
* [`proxy_http_version`](#proxy_http_version)
* [`proxy_read_timeout`](#proxy_read_timeout)
* [`proxy_redirect`](#proxy_redirect)
* [`proxy_send_timeout`](#proxy_send_timeout)
* [`proxy_set_header`](#proxy_set_header)
* [`proxy_hide_header`](#proxy_hide_header)
* [`proxy_pass_header`](#proxy_pass_header)
* [`proxy_ignore_header`](#proxy_ignore_header)
* [`proxy_max_temp_file_size`](#proxy_max_temp_file_size)
* [`proxy_busy_buffers_size`](#proxy_busy_buffers_size)
* [`sendfile`](#sendfile)
* [`server_tokens`](#server_tokens)
* [`spdy`](#spdy)
* [`http2`](#http2)
* [`ssl_stapling`](#ssl_stapling)
* [`ssl_stapling_verify`](#ssl_stapling_verify)
* [`snippets_dir`](#snippets_dir)
* [`manage_snippets_dir`](#manage_snippets_dir)
* [`types_hash_bucket_size`](#types_hash_bucket_size)
* [`types_hash_max_size`](#types_hash_max_size)
* [`worker_connections`](#worker_connections)
* [`ssl_prefer_server_ciphers`](#ssl_prefer_server_ciphers)
* [`worker_processes`](#worker_processes)
* [`worker_rlimit_nofile`](#worker_rlimit_nofile)
* [`pcre_jit`](#pcre_jit)
* [`ssl_protocols`](#ssl_protocols)
* [`ssl_ciphers`](#ssl_ciphers)
* [`ssl_dhparam`](#ssl_dhparam)
* [`ssl_ecdh_curve`](#ssl_ecdh_curve)
* [`ssl_session_cache`](#ssl_session_cache)
* [`ssl_session_timeout`](#ssl_session_timeout)
* [`ssl_session_tickets`](#ssl_session_tickets)
* [`ssl_session_ticket_key`](#ssl_session_ticket_key)
* [`ssl_buffer_size`](#ssl_buffer_size)
* [`ssl_crl`](#ssl_crl)
* [`ssl_stapling_file`](#ssl_stapling_file)
* [`ssl_stapling_responder`](#ssl_stapling_responder)
* [`ssl_trusted_certificate`](#ssl_trusted_certificate)
* [`ssl_verify_depth`](#ssl_verify_depth)
* [`ssl_password_file`](#ssl_password_file)
* [`package_ensure`](#package_ensure)
* [`package_name`](#package_name)
* [`package_source`](#package_source)
* [`package_flavor`](#package_flavor)
* [`manage_repo`](#manage_repo)
* [`mime_types`](#mime_types)
* [`mime_types_preserve_defaults`](#mime_types_preserve_defaults)
* [`repo_release`](#repo_release)
* [`passenger_package_ensure`](#passenger_package_ensure)
* [`repo_source`](#repo_source)
* [`service_ensure`](#service_ensure)
* [`service_enable`](#service_enable)
* [`service_flags`](#service_flags)
* [`service_restart`](#service_restart)
* [`service_name`](#service_name)
* [`service_manage`](#service_manage)
* [`geo_mappings`](#geo_mappings)
* [`geo_mappings_defaults`](#geo_mappings_defaults)
* [`string_mappings`](#string_mappings)
* [`string_mappings_defaults`](#string_mappings_defaults)
* [`nginx_locations`](#nginx_locations)
* [`nginx_locations_defaults`](#nginx_locations_defaults)
* [`nginx_mailhosts`](#nginx_mailhosts)
* [`nginx_mailhosts_defaults`](#nginx_mailhosts_defaults)
* [`nginx_servers`](#nginx_servers)
* [`nginx_servers_defaults`](#nginx_servers_defaults)
* [`nginx_streamhosts`](#nginx_streamhosts)
* [`nginx_streamhosts_defaults`](#nginx_streamhosts_defaults)
* [`nginx_upstreams`](#nginx_upstreams)
* [`nginx_upstreams_defaults`](#nginx_upstreams_defaults)
* [`purge_passenger_repo`](#purge_passenger_repo)

##### <a name="include_modules_enabled"></a>`include_modules_enabled`

Data type: `Boolean`

When set, nginx will include module configurations files installed in the
/etc/nginx/modules-enabled directory.

Default value: `$nginx::params::include_modules_enabled`

##### <a name="passenger_package_name"></a>`passenger_package_name`

Data type: `String[1]`

The name of the package to install in order for the passenger module of
nginx being usable.

Default value: `$nginx::params::passenger_package_name`

##### <a name="nginx_version"></a>`nginx_version`

Data type: `String[1]`

The version of nginx installed (or being installed).
Unfortunately, different versions of nginx may need configuring
differently.  The default is derived from the version of nginx
already installed.  If the fact is unavailable, it defaults to '1.6.0'.
You may need to set this manually to get a working and idempotent
configuration.

Default value: `pick(fact('nginx_version'), '1.6.0')`

##### <a name="debug_connections"></a>`debug_connections`

Data type: `Array[Nginx::DebugConnection]`

Configures nginx `debug_connection` lines in the `events` section of the nginx config.
See http://nginx.org/en/docs/ngx_core_module.html#debug_connection

Default value: `[]`

##### <a name="service_config_check"></a>`service_config_check`

Data type: `Boolean`

whether to en- or disable the config check via nginx -t on config changes

Default value: ``false``

##### <a name="service_config_check_command"></a>`service_config_check_command`

Data type: `String`

Command to execute to validate the generated configuration.

Default value: `'nginx -t'`

##### <a name="reset_timedout_connection"></a>`reset_timedout_connection`

Data type: `Optional[Enum['on', 'off']]`

Enables or disables resetting timed out connections and connections closed
with the non-standard code 444.

Default value: ``undef``

##### <a name="client_body_temp_path"></a>`client_body_temp_path`

Data type: `Variant[Stdlib::Absolutepath, Boolean]`



Default value: `$nginx::params::client_body_temp_path`

##### <a name="confd_only"></a>`confd_only`

Data type: `Boolean`



Default value: ``false``

##### <a name="confd_purge"></a>`confd_purge`

Data type: `Boolean`



Default value: ``false``

##### <a name="conf_dir"></a>`conf_dir`

Data type: `Any`



Default value: `$nginx::params::conf_dir`

##### <a name="daemon"></a>`daemon`

Data type: `Optional[Enum['on', 'off']]`



Default value: ``undef``

##### <a name="daemon_user"></a>`daemon_user`

Data type: `Any`



Default value: `$nginx::params::daemon_user`

##### <a name="daemon_group"></a>`daemon_group`

Data type: `Any`



Default value: ``undef``

##### <a name="dynamic_modules"></a>`dynamic_modules`

Data type: `Array[String]`



Default value: `[]`

##### <a name="global_owner"></a>`global_owner`

Data type: `Any`



Default value: `$nginx::params::global_owner`

##### <a name="global_group"></a>`global_group`

Data type: `Any`



Default value: `$nginx::params::global_group`

##### <a name="global_mode"></a>`global_mode`

Data type: `Any`



Default value: `$nginx::params::global_mode`

##### <a name="limit_req_zone"></a>`limit_req_zone`

Data type: `Optional[Variant[String[1], Array[String[1]]]]`



Default value: ``undef``

##### <a name="log_dir"></a>`log_dir`

Data type: `Stdlib::Absolutepath`



Default value: `$nginx::params::log_dir`

##### <a name="log_user"></a>`log_user`

Data type: `String[1]`



Default value: `$nginx::params::log_user`

##### <a name="log_group"></a>`log_group`

Data type: `String[1]`



Default value: `$nginx::params::log_group`

##### <a name="log_mode"></a>`log_mode`

Data type: `Stdlib::Filemode`



Default value: `$nginx::params::log_mode`

##### <a name="http_access_log"></a>`http_access_log`

Data type: `Variant[String, Array[String]]`



Default value: `"${log_dir}/${nginx::params::http_access_log_file}"`

##### <a name="http_format_log"></a>`http_format_log`

Data type: `Optional[String]`



Default value: ``undef``

##### <a name="nginx_error_log"></a>`nginx_error_log`

Data type: `Variant[String, Array[String]]`



Default value: `"${log_dir}/${nginx::params::nginx_error_log_file}"`

##### <a name="nginx_error_log_severity"></a>`nginx_error_log_severity`

Data type: `Nginx::ErrorLogSeverity`



Default value: `'error'`

##### <a name="pid"></a>`pid`

Data type: `Any`



Default value: `$nginx::params::pid`

##### <a name="proxy_temp_path"></a>`proxy_temp_path`

Data type: `Variant[Stdlib::Absolutepath, Boolean]`



Default value: `$nginx::params::proxy_temp_path`

##### <a name="root_group"></a>`root_group`

Data type: `Any`



Default value: `$nginx::params::root_group`

##### <a name="run_dir"></a>`run_dir`

Data type: `Any`



Default value: `$nginx::params::run_dir`

##### <a name="sites_available_owner"></a>`sites_available_owner`

Data type: `Any`



Default value: `$nginx::params::sites_available_owner`

##### <a name="sites_available_group"></a>`sites_available_group`

Data type: `Any`



Default value: `$nginx::params::sites_available_group`

##### <a name="sites_available_mode"></a>`sites_available_mode`

Data type: `Any`



Default value: `$nginx::params::sites_available_mode`

##### <a name="super_user"></a>`super_user`

Data type: `Boolean`



Default value: `$nginx::params::super_user`

##### <a name="temp_dir"></a>`temp_dir`

Data type: `Any`



Default value: `$nginx::params::temp_dir`

##### <a name="server_purge"></a>`server_purge`

Data type: `Boolean`



Default value: ``false``

##### <a name="conf_template"></a>`conf_template`

Data type: `String[1]`



Default value: `'nginx/conf.d/nginx.conf.erb'`

##### <a name="fastcgi_conf_template"></a>`fastcgi_conf_template`

Data type: `String[1]`



Default value: `'nginx/server/fastcgi.conf.erb'`

##### <a name="uwsgi_params_template"></a>`uwsgi_params_template`

Data type: `String[1]`



Default value: `'nginx/server/uwsgi_params.erb'`

##### <a name="absolute_redirect"></a>`absolute_redirect`

Data type: `Optional[Enum['on', 'off']]`



Default value: ``undef``

##### <a name="accept_mutex"></a>`accept_mutex`

Data type: `Enum['on', 'off']`



Default value: `'on'`

##### <a name="accept_mutex_delay"></a>`accept_mutex_delay`

Data type: `Any`



Default value: `'500ms'`

##### <a name="client_body_buffer_size"></a>`client_body_buffer_size`

Data type: `Any`



Default value: `'128k'`

##### <a name="client_max_body_size"></a>`client_max_body_size`

Data type: `String`



Default value: `'10m'`

##### <a name="client_body_timeout"></a>`client_body_timeout`

Data type: `Any`



Default value: `'60s'`

##### <a name="send_timeout"></a>`send_timeout`

Data type: `Any`



Default value: `'60s'`

##### <a name="lingering_timeout"></a>`lingering_timeout`

Data type: `Any`



Default value: `'5s'`

##### <a name="lingering_close"></a>`lingering_close`

Data type: `Optional[Enum['on','off','always']]`



Default value: ``undef``

##### <a name="lingering_time"></a>`lingering_time`

Data type: `Optional[String[1]]`



Default value: ``undef``

##### <a name="etag"></a>`etag`

Data type: `Optional[Enum['on', 'off']]`



Default value: ``undef``

##### <a name="events_use"></a>`events_use`

Data type: `Optional[String]`



Default value: ``undef``

##### <a name="fastcgi_cache_inactive"></a>`fastcgi_cache_inactive`

Data type: `String`



Default value: `'20m'`

##### <a name="fastcgi_cache_key"></a>`fastcgi_cache_key`

Data type: `Optional[String]`



Default value: ``undef``

##### <a name="fastcgi_cache_keys_zone"></a>`fastcgi_cache_keys_zone`

Data type: `String`



Default value: `'d3:100m'`

##### <a name="fastcgi_cache_levels"></a>`fastcgi_cache_levels`

Data type: `String`



Default value: `'1'`

##### <a name="fastcgi_cache_max_size"></a>`fastcgi_cache_max_size`

Data type: `String`



Default value: `'500m'`

##### <a name="fastcgi_cache_path"></a>`fastcgi_cache_path`

Data type: `Optional[String]`



Default value: ``undef``

##### <a name="fastcgi_cache_use_stale"></a>`fastcgi_cache_use_stale`

Data type: `Optional[String]`



Default value: ``undef``

##### <a name="gzip"></a>`gzip`

Data type: `Enum['on', 'off']`



Default value: `'off'`

##### <a name="gzip_buffers"></a>`gzip_buffers`

Data type: `Any`



Default value: ``undef``

##### <a name="gzip_comp_level"></a>`gzip_comp_level`

Data type: `Any`



Default value: `1`

##### <a name="gzip_disable"></a>`gzip_disable`

Data type: `Any`



Default value: `'msie6'`

##### <a name="gzip_min_length"></a>`gzip_min_length`

Data type: `Any`



Default value: `20`

##### <a name="gzip_http_version"></a>`gzip_http_version`

Data type: `Any`



Default value: `1.1`

##### <a name="gzip_proxied"></a>`gzip_proxied`

Data type: `Any`



Default value: `'off'`

##### <a name="gzip_types"></a>`gzip_types`

Data type: `Any`



Default value: ``undef``

##### <a name="gzip_vary"></a>`gzip_vary`

Data type: `Enum['on', 'off']`



Default value: `'off'`

##### <a name="gzip_static"></a>`gzip_static`

Data type: `Optional[Enum['on', 'off', 'always']]`



Default value: ``undef``

##### <a name="http_cfg_prepend"></a>`http_cfg_prepend`

Data type: `Optional[Variant[Hash, Array]]`



Default value: ``undef``

##### <a name="http_cfg_append"></a>`http_cfg_append`

Data type: `Optional[Variant[Hash, Array]]`



Default value: ``undef``

##### <a name="http_raw_prepend"></a>`http_raw_prepend`

Data type: `Optional[Variant[Array[String], String]]`



Default value: ``undef``

##### <a name="http_raw_append"></a>`http_raw_append`

Data type: `Optional[Variant[Array[String], String]]`



Default value: ``undef``

##### <a name="http_tcp_nodelay"></a>`http_tcp_nodelay`

Data type: `Enum['on', 'off']`



Default value: `'on'`

##### <a name="http_tcp_nopush"></a>`http_tcp_nopush`

Data type: `Enum['on', 'off']`



Default value: `'off'`

##### <a name="keepalive_timeout"></a>`keepalive_timeout`

Data type: `Any`



Default value: `'65s'`

##### <a name="keepalive_requests"></a>`keepalive_requests`

Data type: `Any`



Default value: `'100'`

##### <a name="log_format"></a>`log_format`

Data type: `Any`



Default value: `{}`

##### <a name="mail"></a>`mail`

Data type: `Boolean`



Default value: ``false``

##### <a name="mime_types_path"></a>`mime_types_path`

Data type: `Variant[String, Boolean]`



Default value: `'mime.types'`

##### <a name="stream"></a>`stream`

Data type: `Boolean`



Default value: ``false``

##### <a name="multi_accept"></a>`multi_accept`

Data type: `String`



Default value: `'off'`

##### <a name="names_hash_bucket_size"></a>`names_hash_bucket_size`

Data type: `Integer`



Default value: `64`

##### <a name="names_hash_max_size"></a>`names_hash_max_size`

Data type: `Integer`



Default value: `512`

##### <a name="nginx_cfg_prepend"></a>`nginx_cfg_prepend`

Data type: `Any`



Default value: ``false``

##### <a name="proxy_buffers"></a>`proxy_buffers`

Data type: `String`



Default value: `'32 4k'`

##### <a name="proxy_buffer_size"></a>`proxy_buffer_size`

Data type: `String`



Default value: `'8k'`

##### <a name="proxy_cache_inactive"></a>`proxy_cache_inactive`

Data type: `String`



Default value: `'20m'`

##### <a name="proxy_cache_keys_zone"></a>`proxy_cache_keys_zone`

Data type: `String`



Default value: `'d2:100m'`

##### <a name="proxy_cache_levels"></a>`proxy_cache_levels`

Data type: `String`



Default value: `'1'`

##### <a name="proxy_cache_max_size"></a>`proxy_cache_max_size`

Data type: `String`



Default value: `'500m'`

##### <a name="proxy_cache_path"></a>`proxy_cache_path`

Data type: `Optional[Variant[Hash, String]]`



Default value: ``undef``

##### <a name="proxy_cache_loader_files"></a>`proxy_cache_loader_files`

Data type: `Optional[Integer]`



Default value: ``undef``

##### <a name="proxy_cache_loader_sleep"></a>`proxy_cache_loader_sleep`

Data type: `Optional[String]`



Default value: ``undef``

##### <a name="proxy_cache_loader_threshold"></a>`proxy_cache_loader_threshold`

Data type: `Optional[String]`



Default value: ``undef``

##### <a name="proxy_use_temp_path"></a>`proxy_use_temp_path`

Data type: `Optional[Enum['on', 'off']]`



Default value: ``undef``

##### <a name="proxy_connect_timeout"></a>`proxy_connect_timeout`

Data type: `Any`



Default value: `'90s'`

##### <a name="proxy_headers_hash_bucket_size"></a>`proxy_headers_hash_bucket_size`

Data type: `Integer`



Default value: `64`

##### <a name="proxy_http_version"></a>`proxy_http_version`

Data type: `Optional[String]`



Default value: ``undef``

##### <a name="proxy_read_timeout"></a>`proxy_read_timeout`

Data type: `Any`



Default value: `'90s'`

##### <a name="proxy_redirect"></a>`proxy_redirect`

Data type: `Any`



Default value: ``undef``

##### <a name="proxy_send_timeout"></a>`proxy_send_timeout`

Data type: `Any`



Default value: `'90s'`

##### <a name="proxy_set_header"></a>`proxy_set_header`

Data type: `Array`



Default value: `[
    'Host $host',
    'X-Real-IP $remote_addr',
    'X-Forwarded-For $proxy_add_x_forwarded_for',
    'X-Forwarded-Proto $scheme',
    'Proxy ""',
  ]`

##### <a name="proxy_hide_header"></a>`proxy_hide_header`

Data type: `Array`



Default value: `[]`

##### <a name="proxy_pass_header"></a>`proxy_pass_header`

Data type: `Array`



Default value: `[]`

##### <a name="proxy_ignore_header"></a>`proxy_ignore_header`

Data type: `Array`



Default value: `[]`

##### <a name="proxy_max_temp_file_size"></a>`proxy_max_temp_file_size`

Data type: `Optional[Nginx::Size]`



Default value: ``undef``

##### <a name="proxy_busy_buffers_size"></a>`proxy_busy_buffers_size`

Data type: `Optional[Nginx::Size]`



Default value: ``undef``

##### <a name="sendfile"></a>`sendfile`

Data type: `Enum['on', 'off']`



Default value: `'on'`

##### <a name="server_tokens"></a>`server_tokens`

Data type: `Enum['on', 'off']`



Default value: `'on'`

##### <a name="spdy"></a>`spdy`

Data type: `Enum['on', 'off']`



Default value: `'off'`

##### <a name="http2"></a>`http2`

Data type: `Enum['on', 'off']`



Default value: `'off'`

##### <a name="ssl_stapling"></a>`ssl_stapling`

Data type: `Enum['on', 'off']`



Default value: `'off'`

##### <a name="ssl_stapling_verify"></a>`ssl_stapling_verify`

Data type: `Enum['on', 'off']`



Default value: `'off'`

##### <a name="snippets_dir"></a>`snippets_dir`

Data type: `Stdlib::Absolutepath`



Default value: `$nginx::params::snippets_dir`

##### <a name="manage_snippets_dir"></a>`manage_snippets_dir`

Data type: `Boolean`



Default value: ``true``

##### <a name="types_hash_bucket_size"></a>`types_hash_bucket_size`

Data type: `Any`



Default value: `'512'`

##### <a name="types_hash_max_size"></a>`types_hash_max_size`

Data type: `Any`



Default value: `'1024'`

##### <a name="worker_connections"></a>`worker_connections`

Data type: `Integer`



Default value: `1024`

##### <a name="ssl_prefer_server_ciphers"></a>`ssl_prefer_server_ciphers`

Data type: `Enum['on', 'off']`



Default value: `'on'`

##### <a name="worker_processes"></a>`worker_processes`

Data type: `Variant[Integer, Enum['auto']]`



Default value: `'auto'`

##### <a name="worker_rlimit_nofile"></a>`worker_rlimit_nofile`

Data type: `Integer`



Default value: `1024`

##### <a name="pcre_jit"></a>`pcre_jit`

Data type: `Optional[Enum['on', 'off']]`



Default value: ``undef``

##### <a name="ssl_protocols"></a>`ssl_protocols`

Data type: `String`



Default value: `'TLSv1 TLSv1.1 TLSv1.2'`

##### <a name="ssl_ciphers"></a>`ssl_ciphers`

Data type: `String`



Default value: `'ECDHE-ECDSA-CHACHA20-POLY1305:ECDHE-RSA-CHACHA20-POLY1305:ECDHE-ECDSA-AES128-GCM-SHA256:ECDHE-RSA-AES128-GCM-SHA256:ECDHE-ECDSA-AES256-GCM-SHA384:ECDHE-RSA-AES256-GCM-SHA384:DHE-RSA-AES128-GCM-SHA256:DHE-RSA-AES256-GCM-SHA384:ECDHE-ECDSA-AES128-SHA256:ECDHE-RSA-AES128-SHA256:ECDHE-ECDSA-AES128-SHA:ECDHE-RSA-AES256-SHA384:ECDHE-RSA-AES128-SHA:ECDHE-ECDSA-AES256-SHA384:ECDHE-ECDSA-AES256-SHA:ECDHE-RSA-AES256-SHA:DHE-RSA-AES128-SHA256:DHE-RSA-AES128-SHA:DHE-RSA-AES256-SHA256:DHE-RSA-AES256-SHA:ECDHE-ECDSA-DES-CBC3-SHA:ECDHE-RSA-DES-CBC3-SHA:EDH-RSA-DES-CBC3-SHA:AES128-GCM-SHA256:AES256-GCM-SHA384:AES128-SHA256:AES256-SHA256:AES128-SHA:AES256-SHA:DES-CBC3-SHA:!DSS'`

##### <a name="ssl_dhparam"></a>`ssl_dhparam`

Data type: `Optional[Stdlib::Unixpath]`



Default value: ``undef``

##### <a name="ssl_ecdh_curve"></a>`ssl_ecdh_curve`

Data type: `Optional[String]`



Default value: ``undef``

##### <a name="ssl_session_cache"></a>`ssl_session_cache`

Data type: `String`



Default value: `'shared:SSL:10m'`

##### <a name="ssl_session_timeout"></a>`ssl_session_timeout`

Data type: `String`



Default value: `'5m'`

##### <a name="ssl_session_tickets"></a>`ssl_session_tickets`

Data type: `Optional[Enum['on', 'off']]`



Default value: ``undef``

##### <a name="ssl_session_ticket_key"></a>`ssl_session_ticket_key`

Data type: `Optional[Stdlib::Absolutepath]`



Default value: ``undef``

##### <a name="ssl_buffer_size"></a>`ssl_buffer_size`

Data type: `Optional[String]`



Default value: ``undef``

##### <a name="ssl_crl"></a>`ssl_crl`

Data type: `Optional[Stdlib::Absolutepath]`



Default value: ``undef``

##### <a name="ssl_stapling_file"></a>`ssl_stapling_file`

Data type: `Optional[Stdlib::Absolutepath]`



Default value: ``undef``

##### <a name="ssl_stapling_responder"></a>`ssl_stapling_responder`

Data type: `Optional[String]`



Default value: ``undef``

##### <a name="ssl_trusted_certificate"></a>`ssl_trusted_certificate`

Data type: `Optional[Stdlib::Absolutepath]`



Default value: ``undef``

##### <a name="ssl_verify_depth"></a>`ssl_verify_depth`

Data type: `Optional[Integer]`



Default value: ``undef``

##### <a name="ssl_password_file"></a>`ssl_password_file`

Data type: `Optional[Stdlib::Absolutepath]`



Default value: ``undef``

##### <a name="package_ensure"></a>`package_ensure`

Data type: `Any`



Default value: `present`

##### <a name="package_name"></a>`package_name`

Data type: `Any`



Default value: `$nginx::params::package_name`

##### <a name="package_source"></a>`package_source`

Data type: `Any`



Default value: `'nginx'`

##### <a name="package_flavor"></a>`package_flavor`

Data type: `Any`



Default value: ``undef``

##### <a name="manage_repo"></a>`manage_repo`

Data type: `Boolean`



Default value: `$nginx::params::manage_repo`

##### <a name="mime_types"></a>`mime_types`

Data type: `Hash[String[1], String[1]]`



Default value: `$nginx::params::mime_types`

##### <a name="mime_types_preserve_defaults"></a>`mime_types_preserve_defaults`

Data type: `Boolean`



Default value: ``false``

##### <a name="repo_release"></a>`repo_release`

Data type: `Optional[String]`



Default value: ``undef``

##### <a name="passenger_package_ensure"></a>`passenger_package_ensure`

Data type: `Any`



Default value: `'present'`

##### <a name="repo_source"></a>`repo_source`

Data type: `Optional[Stdlib::HTTPUrl]`



Default value: ``undef``

##### <a name="service_ensure"></a>`service_ensure`

Data type: `Stdlib::Ensure::Service`



Default value: `'running'`

##### <a name="service_enable"></a>`service_enable`

Data type: `Any`



Default value: ``true``

##### <a name="service_flags"></a>`service_flags`

Data type: `Any`



Default value: ``undef``

##### <a name="service_restart"></a>`service_restart`

Data type: `Any`



Default value: ``undef``

##### <a name="service_name"></a>`service_name`

Data type: `Any`



Default value: `'nginx'`

##### <a name="service_manage"></a>`service_manage`

Data type: `Any`



Default value: ``true``

##### <a name="geo_mappings"></a>`geo_mappings`

Data type: `Hash`



Default value: `{}`

##### <a name="geo_mappings_defaults"></a>`geo_mappings_defaults`

Data type: `Hash`



Default value: `{}`

##### <a name="string_mappings"></a>`string_mappings`

Data type: `Hash`



Default value: `{}`

##### <a name="string_mappings_defaults"></a>`string_mappings_defaults`

Data type: `Hash`



Default value: `{}`

##### <a name="nginx_locations"></a>`nginx_locations`

Data type: `Hash`



Default value: `{}`

##### <a name="nginx_locations_defaults"></a>`nginx_locations_defaults`

Data type: `Hash`



Default value: `{}`

##### <a name="nginx_mailhosts"></a>`nginx_mailhosts`

Data type: `Hash`



Default value: `{}`

##### <a name="nginx_mailhosts_defaults"></a>`nginx_mailhosts_defaults`

Data type: `Hash`



Default value: `{}`

##### <a name="nginx_servers"></a>`nginx_servers`

Data type: `Hash`



Default value: `{}`

##### <a name="nginx_servers_defaults"></a>`nginx_servers_defaults`

Data type: `Hash`



Default value: `{}`

##### <a name="nginx_streamhosts"></a>`nginx_streamhosts`

Data type: `Hash`



Default value: `{}`

##### <a name="nginx_streamhosts_defaults"></a>`nginx_streamhosts_defaults`

Data type: `Hash`



Default value: `{}`

##### <a name="nginx_upstreams"></a>`nginx_upstreams`

Data type: `Hash`



Default value: `{}`

##### <a name="nginx_upstreams_defaults"></a>`nginx_upstreams_defaults`

Data type: `Nginx::UpstreamDefaults`



Default value: `{}`

##### <a name="purge_passenger_repo"></a>`purge_passenger_repo`

Data type: `Boolean`



Default value: ``true``

## Defined types

### <a name="nginxresourcegeo"></a>`nginx::resource::geo`

Create a new geo mapping entry for NGINX

#### Examples

##### Puppet usage

```puppet
nginx::resource::geo { 'client_network':
  ensure          => present,
  ranges          => false,
  default         => extra,
  proxy_recursive => false,
  proxies         => [ '192.168.99.99' ],
  networks        => {
    '10.0.0.0/8'     => 'intra',
    '172.16.0.0/12'  => 'intra',
    '192.168.0.0/16' => 'intra',
  }
}
```

##### Hiera usage

```puppet
nginx::geo_mappings:
  client_network:
    ensure: present
    ranges: false
    default: 'extra'
    proxy_recursive: false
    proxies:
       - 192.168.99.99
    networks:
      '10.0.0.0/8': 'intra'
      '172.16.0.0/12': 'intra'
      '192.168.0.0/16': 'intra'
```

#### Parameters

The following parameters are available in the `nginx::resource::geo` defined type:

* [`networks`](#networks)
* [`default`](#default)
* [`ensure`](#ensure)
* [`ranges`](#ranges)
* [`address`](#address)
* [`delete`](#delete)
* [`proxy_recursive`](#proxy_recursive)
* [`proxies`](#proxies)

##### <a name="networks"></a>`networks`

Data type: `Hash`

Hash of geo lookup keys and resultant values

##### <a name="default"></a>`default`

Data type: `Optional[String]`

Sets the resulting value if the source value fails to match any of the
variants.

Default value: ``undef``

##### <a name="ensure"></a>`ensure`

Data type: `Enum['present', 'absent']`

Enables or disables the specified location

Default value: `'present'`

##### <a name="ranges"></a>`ranges`

Data type: `Boolean`

Indicates that lookup keys (network addresses) are specified as ranges.

Default value: ``false``

##### <a name="address"></a>`address`

Data type: `Optional[String]`

Nginx defaults to using $remote_addr for testing.  This allows you to
override that with another variable name (automatically prefixed with $)

Default value: ``undef``

##### <a name="delete"></a>`delete`

Data type: `Optional[String]`

deletes the specified network (see: geo module docs)

Default value: ``undef``

##### <a name="proxy_recursive"></a>`proxy_recursive`

Data type: `Optional[Boolean]`

Changes the behavior of address acquisition when specifying trusted
proxies via 'proxies' directive

Default value: ``undef``

##### <a name="proxies"></a>`proxies`

Data type: `Optional[Array]`

Hash of network->value mappings.

Default value: ``undef``

### <a name="nginxresourcelocation"></a>`nginx::resource::location`

Create a new location entry within a virtual host

#### Examples

##### Simple example

```puppet
nginx::resource::location { 'test2.local-bob':
  ensure   => present,
  www_root => '/var/www/bob',
  location => '/bob',
  server   => 'test2.local',
}
```

##### Use one location in multiple servers

```puppet
nginx::resource::location { 'test2.local-bob':
  ensure   => present,
  www_root => '/var/www/bob',
  location => '/bob',
  server   => ['test1.local','test2.local'],
}
```

##### Custom config example to limit location on localhost, create a hash with any extra custom config you want.

```puppet
$my_config = {
  'access_log' => 'off',
  'allow'      => '127.0.0.1',
  'deny'       => 'all'
}
nginx::resource::location { 'test2.local-bob':
  ensure              => present,
  www_root            => '/var/www/bob',
  location            => '/bob',
  server              => 'test2.local',
  location_cfg_append => $my_config,
}
```

##### Add Custom fastcgi_params

```puppet
nginx::resource::location { 'test2.local-bob':
  ensure        => present,
  www_root      => '/var/www/bob',
  location      => '/bob',
  server        => 'test2.local',
  fastcgi_param => {
     'APP_ENV'  => 'local',
  }
}
```

##### Add Custom uwsgi_params

```puppet
nginx::resource::location { 'test2.local-bob':
  ensure       => present,
  www_root     => '/var/www/bob',
  location     => '/bob',
  server       => 'test2.local',
  uwsgi_param  => {
     'APP_ENV' => 'local',
  }
}
```

#### Parameters

The following parameters are available in the `nginx::resource::location` defined type:

* [`ensure`](#ensure)
* [`internal`](#internal)
* [`server`](#server)
* [`location`](#location)
* [`location_satisfy`](#location_satisfy)
* [`location_allow`](#location_allow)
* [`location_deny`](#location_deny)
* [`www_root`](#www_root)
* [`autoindex`](#autoindex)
* [`autoindex_exact_size`](#autoindex_exact_size)
* [`autoindex_format`](#autoindex_format)
* [`autoindex_localtime`](#autoindex_localtime)
* [`index_files`](#index_files)
* [`proxy`](#proxy)
* [`proxy_redirect`](#proxy_redirect)
* [`proxy_read_timeout`](#proxy_read_timeout)
* [`proxy_connect_timeout`](#proxy_connect_timeout)
* [`proxy_send_timeout`](#proxy_send_timeout)
* [`proxy_set_header`](#proxy_set_header)
* [`proxy_hide_header`](#proxy_hide_header)
* [`proxy_pass_header`](#proxy_pass_header)
* [`proxy_ignore_header`](#proxy_ignore_header)
* [`proxy_next_upstream`](#proxy_next_upstream)
* [`fastcgi`](#fastcgi)
* [`fastcgi_param`](#fastcgi_param)
* [`fastcgi_params`](#fastcgi_params)
* [`fastcgi_script`](#fastcgi_script)
* [`fastcgi_split_path`](#fastcgi_split_path)
* [`uwsgi`](#uwsgi)
* [`uwsgi_param`](#uwsgi_param)
* [`uwsgi_params`](#uwsgi_params)
* [`uwsgi_read_timeout`](#uwsgi_read_timeout)
* [`ssl`](#ssl)
* [`ssl_only`](#ssl_only)
* [`location_alias`](#location_alias)
* [`stub_status`](#stub_status)
* [`raw_prepend`](#raw_prepend)
* [`raw_append`](#raw_append)
* [`limit_zone`](#limit_zone)
* [`location_custom_cfg`](#location_custom_cfg)
* [`location_cfg_prepend`](#location_cfg_prepend)
* [`location_custom_cfg_prepend`](#location_custom_cfg_prepend)
* [`location_custom_cfg_append`](#location_custom_cfg_append)
* [`location_cfg_append`](#location_cfg_append)
* [`include`](#include)
* [`try_files`](#try_files)
* [`proxy_cache`](#proxy_cache)
* [`proxy_cache_key`](#proxy_cache_key)
* [`proxy_cache_use_stale`](#proxy_cache_use_stale)
* [`proxy_cache_valid`](#proxy_cache_valid)
* [`proxy_cache_lock`](#proxy_cache_lock)
* [`proxy_cache_bypass`](#proxy_cache_bypass)
* [`proxy_method`](#proxy_method)
* [`proxy_http_version`](#proxy_http_version)
* [`proxy_set_body`](#proxy_set_body)
* [`proxy_buffering`](#proxy_buffering)
* [`proxy_request_buffering`](#proxy_request_buffering)
* [`proxy_max_temp_file_size`](#proxy_max_temp_file_size)
* [`proxy_busy_buffers_size`](#proxy_busy_buffers_size)
* [`absolute_redirect`](#absolute_redirect)
* [`auth_basic`](#auth_basic)
* [`auth_basic_user_file`](#auth_basic_user_file)
* [`auth_request`](#auth_request)
* [`priority`](#priority)
* [`mp4`](#mp4)
* [`flv`](#flv)
* [`expires`](#expires)
* [`add_header`](#add_header)
* [`gzip_static`](#gzip_static)
* [`reset_timedout_connection`](#reset_timedout_connection)
* [`fastcgi_index`](#fastcgi_index)
* [`rewrite_rules`](#rewrite_rules)

##### <a name="ensure"></a>`ensure`

Data type: `Enum['present', 'absent']`

Enables or disables the specified location
(present|absent)

Default value: `'present'`

##### <a name="internal"></a>`internal`

Data type: `Boolean`

Indicates whether or not this location can be
used for internal requests only. Default: false

Default value: ``false``

##### <a name="server"></a>`server`

Data type: `Variant[String[1],Array[String[1],1]]`

Defines a server or list of servers that include this location

Default value: ``undef``

##### <a name="location"></a>`location`

Data type: `String`

Specifies the URI associated with this location
entry

Default value: `$name`

##### <a name="location_satisfy"></a>`location_satisfy`

Data type: `Optional[Enum['any', 'all']]`

Allows access if all (all) or at least one (any) of the auth modules allow access.

Default value: ``undef``

##### <a name="location_allow"></a>`location_allow`

Data type: `Optional[Array]`

Locations to allow connections from.

Default value: ``undef``

##### <a name="location_deny"></a>`location_deny`

Data type: `Optional[Array]`

Locations to deny connections from.

Default value: ``undef``

##### <a name="www_root"></a>`www_root`

Data type: `Optional[String]`

Specifies the location on disk for files to be read from. Cannot be set in
conjunction with $proxy

Default value: ``undef``

##### <a name="autoindex"></a>`autoindex`

Data type: `Optional[String]`

Set it on 'on' to activate autoindex directory listing.

Default value: ``undef``

##### <a name="autoindex_exact_size"></a>`autoindex_exact_size`

Data type: `Optional[Enum['on', 'off']]`

Set it on 'on' or 'off' to activate/deactivate autoindex displaying exact
filesize, or rounded to kilobytes, megabytes and gigabytes.

Default value: ``undef``

##### <a name="autoindex_format"></a>`autoindex_format`

Data type: `Optional[Enum['html', 'xml', 'json', 'jsonp']]`

Sets the format of a directory listing.

Default value: ``undef``

##### <a name="autoindex_localtime"></a>`autoindex_localtime`

Data type: `Optional[Enum['on', 'off']]`

Specifies whether times in the directory listing should be output in the
local time zone or UTC.

Default value: ``undef``

##### <a name="index_files"></a>`index_files`

Data type: `Array`

Default index files for NGINX to read when traversing a directory

Default value: `[
    'index.html',
    'index.htm',
    'index.php',
  ]`

##### <a name="proxy"></a>`proxy`

Data type: `Optional[String]`

Proxy server(s) for a location to connect to.  Accepts a single value, can
be used in conjunction with nginx::resource::upstream

Default value: ``undef``

##### <a name="proxy_redirect"></a>`proxy_redirect`

Data type: `Optional[String]`

sets the text, which must be changed in response-header "Location" and
"Refresh" in the response of the proxied server.

Default value: `$nginx::proxy_redirect`

##### <a name="proxy_read_timeout"></a>`proxy_read_timeout`

Data type: `String`

Override the default the proxy read timeout value of 90 seconds

Default value: `$nginx::proxy_read_timeout`

##### <a name="proxy_connect_timeout"></a>`proxy_connect_timeout`

Data type: `String`

Override the default the proxy connect timeout value of 90 seconds

Default value: `$nginx::proxy_connect_timeout`

##### <a name="proxy_send_timeout"></a>`proxy_send_timeout`

Data type: `String`

Override the default the proxy send timeout
value of 90 seconds

Default value: `$nginx::proxy_send_timeout`

##### <a name="proxy_set_header"></a>`proxy_set_header`

Data type: `Array`

Array of server headers to set

Default value: `$nginx::proxy_set_header`

##### <a name="proxy_hide_header"></a>`proxy_hide_header`

Data type: `Array`

Array of server headers to hide

Default value: `$nginx::proxy_hide_header`

##### <a name="proxy_pass_header"></a>`proxy_pass_header`

Data type: `Array`

Array of server headers to pass

Default value: `$nginx::proxy_pass_header`

##### <a name="proxy_ignore_header"></a>`proxy_ignore_header`

Data type: `Array`

Array of server headers to ignore

Default value: `$nginx::proxy_ignore_header`

##### <a name="proxy_next_upstream"></a>`proxy_next_upstream`

Data type: `Optional[String]`

Specify cases a request should be passed to the next server in the upstream.

Default value: ``undef``

##### <a name="fastcgi"></a>`fastcgi`

Data type: `Optional[String]`

location of fastcgi (host:port)

Default value: ``undef``

##### <a name="fastcgi_param"></a>`fastcgi_param`

Data type: `Optional[Hash]`

Set additional custom fastcgi_params

Default value: ``undef``

##### <a name="fastcgi_params"></a>`fastcgi_params`

Data type: `String`

optional alternative fastcgi_params file to use

Default value: `"${nginx::conf_dir}/fastcgi.conf"`

##### <a name="fastcgi_script"></a>`fastcgi_script`

Data type: `Optional[String]`

optional SCRIPT_FILE parameter

Default value: ``undef``

##### <a name="fastcgi_split_path"></a>`fastcgi_split_path`

Data type: `Optional[String]`

Allows settings of fastcgi_split_path_info so that you can split the
script_name and path_info via regex

Default value: ``undef``

##### <a name="uwsgi"></a>`uwsgi`

Data type: `Optional[String]`

location of uwsgi (host:port)

Default value: ``undef``

##### <a name="uwsgi_param"></a>`uwsgi_param`

Data type: `Optional[Hash]`

Set additional custom uwsgi_params

Default value: ``undef``

##### <a name="uwsgi_params"></a>`uwsgi_params`

Data type: `String`

optional alternative uwsgi_params file to use

Default value: `"${nginx::config::conf_dir}/uwsgi_params"`

##### <a name="uwsgi_read_timeout"></a>`uwsgi_read_timeout`

Data type: `Optional[String]`

optional value for uwsgi_read_timeout

Default value: ``undef``

##### <a name="ssl"></a>`ssl`

Data type: `Boolean`

Indicates whether to setup SSL bindings for this location.

Default value: ``false``

##### <a name="ssl_only"></a>`ssl_only`

Data type: `Boolean`

Required if the SSL and normal server have the same port.

Default value: ``false``

##### <a name="location_alias"></a>`location_alias`

Data type: `Optional[String]`

Path to be used as basis for serving requests for this location

Default value: ``undef``

##### <a name="stub_status"></a>`stub_status`

Data type: `Optional[Boolean]`

If true it will point configure module stub_status to provide nginx stats
on location

Default value: ``undef``

##### <a name="raw_prepend"></a>`raw_prepend`

Data type: `Optional[Variant[String, Array]]`

A single string, or an array of strings to prepend to the location
directive (after custom_cfg directives). NOTE: YOU are responsible for a
semicolon on each line that requires one.

Default value: ``undef``

##### <a name="raw_append"></a>`raw_append`

Data type: `Optional[Variant[String, Array]]`

A single string, or an array of strings to append to the location directive
(after custom_cfg directives). NOTE: YOU are responsible for a semicolon on
each line that requires one.

Default value: ``undef``

##### <a name="limit_zone"></a>`limit_zone`

Data type: `Optional[String[1]]`

Apply a limit_req_zone to the location. Expects a string indicating a
previously defined limit_req_zone in the main nginx configuration

Default value: ``undef``

##### <a name="location_custom_cfg"></a>`location_custom_cfg`

Data type: `Optional[Hash]`

Expects a hash with custom directives, cannot be used with other location
types (proxy, fastcgi, root, or stub_status)

Default value: ``undef``

##### <a name="location_cfg_prepend"></a>`location_cfg_prepend`

Data type: `Optional[Hash]`

Expects a hash with extra directives to put before anything else inside
location (used with all other types except custom_cfg)

Default value: ``undef``

##### <a name="location_custom_cfg_prepend"></a>`location_custom_cfg_prepend`

Data type: `Optional[Hash]`

Expects a array with extra directives to put before anything else inside
location (used with all other types except custom_cfg). Used for logical
structures such as if.

Default value: ``undef``

##### <a name="location_custom_cfg_append"></a>`location_custom_cfg_append`

Data type: `Optional[Hash]`

Expects a array with extra directives to put after anything else inside
location (used with all other types except custom_cfg). Used for logical
structures such as if.

Default value: ``undef``

##### <a name="location_cfg_append"></a>`location_cfg_append`

Data type: `Optional[Hash]`

Expects a hash with extra directives to put
after everything else inside location (used with all other types except
custom_cfg)

Default value: ``undef``

##### <a name="include"></a>`include`

Data type: `Optional[Array]`

An array of files to include for this location

Default value: ``undef``

##### <a name="try_files"></a>`try_files`

Data type: `Optional[Array]`

An array of file locations to try

Default value: ``undef``

##### <a name="proxy_cache"></a>`proxy_cache`

Data type: `Optional[String]`

This directive sets name of zone for caching.  The same zone can be used in
multiple places.

Default value: ``undef``

##### <a name="proxy_cache_key"></a>`proxy_cache_key`

Data type: `Optional[String]`

Override the default proxy_cache_key of $scheme$proxy_host$request_uri

Default value: ``undef``

##### <a name="proxy_cache_use_stale"></a>`proxy_cache_use_stale`

Data type: `Optional[String]`

Override the default proxy_cache_use_stale value of off.

Default value: ``undef``

##### <a name="proxy_cache_valid"></a>`proxy_cache_valid`

Data type: `Optional[Variant[Array, String]]`

This directive sets the time for caching different replies.

Default value: ``undef``

##### <a name="proxy_cache_lock"></a>`proxy_cache_lock`

Data type: `Optional[Enum['on', 'off']]`

This directive sets the locking mechanism for pouplating cache.

Default value: ``undef``

##### <a name="proxy_cache_bypass"></a>`proxy_cache_bypass`

Data type: `Optional[Variant[Array, String]]`

Defines conditions which the response will not be cached

Default value: ``undef``

##### <a name="proxy_method"></a>`proxy_method`

Data type: `Optional[String]`

If defined, overrides the HTTP method of the request to be passed to the
backend.

Default value: ``undef``

##### <a name="proxy_http_version"></a>`proxy_http_version`

Data type: `Optional[String]`

Sets the proxy http version

Default value: ``undef``

##### <a name="proxy_set_body"></a>`proxy_set_body`

Data type: `Optional[String]`

If defined, sets the body passed to the backend.

Default value: ``undef``

##### <a name="proxy_buffering"></a>`proxy_buffering`

Data type: `Optional[Enum['on', 'off']]`

If defined, sets the proxy_buffering to the passed value.

Default value: ``undef``

##### <a name="proxy_request_buffering"></a>`proxy_request_buffering`

Data type: `Optional[Enum['on', 'off']]`

If defined, sets the proxy_request_buffering to the passed value.

Default value: ``undef``

##### <a name="proxy_max_temp_file_size"></a>`proxy_max_temp_file_size`

Data type: `Optional[Nginx::Size]`

Sets the maximum size of the temporary buffer file.

Default value: ``undef``

##### <a name="proxy_busy_buffers_size"></a>`proxy_busy_buffers_size`

Data type: `Optional[Nginx::Size]`

Sets the total size of buffers that can be busy sending a response to the
client while the response is not yet fully read.

Default value: ``undef``

##### <a name="absolute_redirect"></a>`absolute_redirect`

Data type: `Optional[Enum['on', 'off']]`

Enables or disables the absolute redirect functionality of nginx

Default value: ``undef``

##### <a name="auth_basic"></a>`auth_basic`

Data type: `Optional[String]`

This directive includes testing name and password with HTTP Basic
Authentication.

Default value: ``undef``

##### <a name="auth_basic_user_file"></a>`auth_basic_user_file`

Data type: `Optional[String]`

This directive sets the htpasswd filename for the authentication realm.

Default value: ``undef``

##### <a name="auth_request"></a>`auth_request`

Data type: `Optional[String]`

This allows you to specify a custom auth endpoint

Default value: ``undef``

##### <a name="priority"></a>`priority`

Data type: `Integer[401,599]`

Location priority. User priority 401-499, 501-599. If the priority is
higher than the default priority (500), the location will be defined after
root, or before root.

Default value: `500`

##### <a name="mp4"></a>`mp4`

Data type: `Boolean`

Indicates whether or not this loation can be
used for mp4 streaming. Default: false

Default value: ``false``

##### <a name="flv"></a>`flv`

Data type: `Boolean`

Indicates whether or not this loation can be
used for flv streaming. Default: false

Default value: ``false``

##### <a name="expires"></a>`expires`

Data type: `Optional[String]`

Setup expires time for locations content

Default value: ``undef``

##### <a name="add_header"></a>`add_header`

Data type: `Hash`

Adds headers to the location block.  If any are specified, locations will
no longer inherit headers from the parent server context

Default value: `{}`

##### <a name="gzip_static"></a>`gzip_static`

Data type: `Optional[Enum['on', 'off', 'always']]`

Defines gzip_static, nginx default is off

Default value: ``undef``

##### <a name="reset_timedout_connection"></a>`reset_timedout_connection`

Data type: `Optional[Enum['on', 'off']]`

Enables or disables resetting timed out connections and connections closed
with the non-standard code 444.

Default value: ``undef``

##### <a name="fastcgi_index"></a>`fastcgi_index`

Data type: `Optional[String]`



Default value: ``undef``

##### <a name="rewrite_rules"></a>`rewrite_rules`

Data type: `Array`



Default value: `[]`

### <a name="nginxresourcemailhost"></a>`nginx::resource::mailhost`

Define a mailhost

#### Examples

##### SMTP server definition

```puppet
nginx::resource::mailhost { 'domain1.example':
  ensure      => present,
  auth_http   => 'server2.example/cgi-bin/auth',
  protocol    => 'smtp',
  listen_port => 587,
  ssl_port    => 465,
  starttls    => 'only',
  xclient     => 'off',
  ssl         => true,
  ssl_cert    => '/tmp/server.crt',
  ssl_key     => '/tmp/server.pem',
}
```

#### Parameters

The following parameters are available in the `nginx::resource::mailhost` defined type:

* [`ensure`](#ensure)
* [`listen_ip`](#listen_ip)
* [`listen_port`](#listen_port)
* [`listen_options`](#listen_options)
* [`ipv6_enable`](#ipv6_enable)
* [`ipv6_listen_ip`](#ipv6_listen_ip)
* [`ipv6_listen_port`](#ipv6_listen_port)
* [`ipv6_listen_options`](#ipv6_listen_options)
* [`ssl`](#ssl)
* [`ssl_cert`](#ssl_cert)
* [`ssl_ciphers`](#ssl_ciphers)
* [`ssl_client_cert`](#ssl_client_cert)
* [`ssl_crl`](#ssl_crl)
* [`ssl_dhparam`](#ssl_dhparam)
* [`ssl_ecdh_curve`](#ssl_ecdh_curve)
* [`ssl_key`](#ssl_key)
* [`ssl_password_file`](#ssl_password_file)
* [`ssl_port`](#ssl_port)
* [`ssl_prefer_server_ciphers`](#ssl_prefer_server_ciphers)
* [`ssl_protocols`](#ssl_protocols)
* [`ssl_session_cache`](#ssl_session_cache)
* [`ssl_session_ticket_key`](#ssl_session_ticket_key)
* [`ssl_session_tickets`](#ssl_session_tickets)
* [`ssl_session_timeout`](#ssl_session_timeout)
* [`ssl_trusted_cert`](#ssl_trusted_cert)
* [`ssl_verify_depth`](#ssl_verify_depth)
* [`starttls`](#starttls)
* [`protocol`](#protocol)
* [`auth_http`](#auth_http)
* [`xclient`](#xclient)
* [`imap_auth`](#imap_auth)
* [`imap_capabilities`](#imap_capabilities)
* [`imap_client_buffer`](#imap_client_buffer)
* [`pop3_auth`](#pop3_auth)
* [`pop3_capabilities`](#pop3_capabilities)
* [`smtp_auth`](#smtp_auth)
* [`smtp_capabilities`](#smtp_capabilities)
* [`proxy_pass_error_message`](#proxy_pass_error_message)
* [`server_name`](#server_name)
* [`raw_prepend`](#raw_prepend)
* [`raw_append`](#raw_append)
* [`mailhost_cfg_append`](#mailhost_cfg_append)
* [`mailhost_cfg_prepend`](#mailhost_cfg_prepend)
* [`auth_http_header`](#auth_http_header)

##### <a name="ensure"></a>`ensure`

Data type: `Enum['absent', 'present']`

Enables or disables the specified mailhost

Default value: `'present'`

##### <a name="listen_ip"></a>`listen_ip`

Data type: `Variant[Array[String], String]`

Default IP Address for NGINX to listen with this server on. Defaults to all interfaces (*)

Default value: `'*'`

##### <a name="listen_port"></a>`listen_port`

Data type: `Stdlib::Port`

Default IP Port for NGINX to listen with this server on.

##### <a name="listen_options"></a>`listen_options`

Data type: `Optional[String]`

Extra options for listen directive like 'default' to catchall.

Default value: ``undef``

##### <a name="ipv6_enable"></a>`ipv6_enable`

Data type: `Boolean`

value to enable/disable IPv6 support (false|true). Module will check to see
if IPv6 support exists on your system before enabling.

Default value: ``false``

##### <a name="ipv6_listen_ip"></a>`ipv6_listen_ip`

Data type: `Variant[Array[String], String]`

Default IPv6 Address for NGINX to listen with this server on. Defaults to
all interfaces (::)

Default value: `'::'`

##### <a name="ipv6_listen_port"></a>`ipv6_listen_port`

Data type: `Stdlib::Port`

Default IPv6 Port for NGINX to listen with this server on.

Default value: `$listen_port`

##### <a name="ipv6_listen_options"></a>`ipv6_listen_options`

Data type: `String`

Extra options for listen directive like 'default' to catchall. Template
will allways add ipv6only=on.  While issue jfryman/puppet-nginx#30 is
discussed, default value is 'default'.

Default value: `'default ipv6only=on'`

##### <a name="ssl"></a>`ssl`

Data type: `Boolean`

Indicates whether to setup SSL bindings for this mailhost.

Default value: ``false``

##### <a name="ssl_cert"></a>`ssl_cert`

Data type: `Optional[String]`

Pre-generated SSL Certificate file to reference for SSL Support. This is
not generated by this module.

Default value: ``undef``

##### <a name="ssl_ciphers"></a>`ssl_ciphers`

Data type: `String`

Override default SSL ciphers.

Default value: `$nginx::ssl_ciphers`

##### <a name="ssl_client_cert"></a>`ssl_client_cert`

Data type: `Optional[String]`

Pre-generated SSL Certificate file to reference for client verify SSL
Support. This is not generated by this module.

Default value: ``undef``

##### <a name="ssl_crl"></a>`ssl_crl`

Data type: `Optional[String]`

String: Specifies CRL path in file system

Default value: ``undef``

##### <a name="ssl_dhparam"></a>`ssl_dhparam`

Data type: `Optional[String]`

This directive specifies a file containing Diffie-Hellman key agreement
protocol cryptographic parameters, in PEM format, utilized for exchanging
session keys between server and client.

Default value: `$nginx::ssl_dhparam`

##### <a name="ssl_ecdh_curve"></a>`ssl_ecdh_curve`

Data type: `Optional[String]`

This directive specifies a curve for ECDHE ciphers.

Default value: ``undef``

##### <a name="ssl_key"></a>`ssl_key`

Data type: `Optional[String]`

Pre-generated SSL Key file to reference for SSL Support. This is not
generated by this module.

Default value: ``undef``

##### <a name="ssl_password_file"></a>`ssl_password_file`

Data type: `Optional[String]`

This directive specifies a file containing passphrases for secret keys.

Default value: ``undef``

##### <a name="ssl_port"></a>`ssl_port`

Data type: `Optional[Stdlib::Port]`

Default IP Port for NGINX to listen with this SSL server on.

Default value: ``undef``

##### <a name="ssl_prefer_server_ciphers"></a>`ssl_prefer_server_ciphers`

Data type: `Enum['on', 'off']`

Specifies that server ciphers should be preferred over client ciphers when
using the SSLv3 and TLS protocols.

Default value: `$nginx::ssl_prefer_server_ciphers`

##### <a name="ssl_protocols"></a>`ssl_protocols`

Data type: `String`

SSL protocols enabled.

Default value: `$nginx::ssl_protocols`

##### <a name="ssl_session_cache"></a>`ssl_session_cache`

Data type: `Optional[String]`

Sets the type and size of the session cache.

Default value: ``undef``

##### <a name="ssl_session_ticket_key"></a>`ssl_session_ticket_key`

Data type: `Optional[String]`

This directive specifies a file containing secret key used to encrypt and
decrypt TLS session tickets.

Default value: ``undef``

##### <a name="ssl_session_tickets"></a>`ssl_session_tickets`

Data type: `Optional[String]`

Whether to enable or disable session resumption through TLS session tickets.

Default value: ``undef``

##### <a name="ssl_session_timeout"></a>`ssl_session_timeout`

Data type: `String`

Specifies a time during which a client may reuse the session parameters
stored in a cache.

Default value: `'5m'`

##### <a name="ssl_trusted_cert"></a>`ssl_trusted_cert`

Data type: `Optional[String]`

Specifies a file with trusted CA certificates in the PEM format used to
verify client certificates and OCSP responses if ssl_stapling is enabled.

Default value: ``undef``

##### <a name="ssl_verify_depth"></a>`ssl_verify_depth`

Data type: `Optional[Integer]`

Sets the verification depth in the client certificates chain.

Default value: ``undef``

##### <a name="starttls"></a>`starttls`

Data type: `Enum['on', 'off', 'only']`

Enable STARTTLS support

Default value: `'off'`

##### <a name="protocol"></a>`protocol`

Data type: `Optional[Enum['imap', 'pop3', 'smtp']]`

Mail protocol to use

Default value: ``undef``

##### <a name="auth_http"></a>`auth_http`

Data type: `Optional[String]`

With this directive you can set the URL to the external HTTP-like server
for authorization.

Default value: ``undef``

##### <a name="xclient"></a>`xclient`

Data type: `Enum['on', 'off']`

Whether to use xclient for smtp

Default value: `'on'`

##### <a name="imap_auth"></a>`imap_auth`

Data type: `Optional[String]`

Sets permitted methods of authentication for IMAP clients.

Default value: ``undef``

##### <a name="imap_capabilities"></a>`imap_capabilities`

Data type: `Optional[Array]`

Sets the IMAP protocol extensions list that is passed to the client in
response to the CAPA command.

Default value: ``undef``

##### <a name="imap_client_buffer"></a>`imap_client_buffer`

Data type: `Optional[String]`

Sets the IMAP commands read buffer size.

Default value: ``undef``

##### <a name="pop3_auth"></a>`pop3_auth`

Data type: `Optional[String]`

Sets permitted methods of authentication for POP3 clients.

Default value: ``undef``

##### <a name="pop3_capabilities"></a>`pop3_capabilities`

Data type: `Optional[Array]`

Sets the POP3 protocol extensions list that is passed to the client in
response to the CAPA command.

Default value: ``undef``

##### <a name="smtp_auth"></a>`smtp_auth`

Data type: `Optional[String]`

Sets permitted methods of SASL authentication for SMTP clients.

Default value: ``undef``

##### <a name="smtp_capabilities"></a>`smtp_capabilities`

Data type: `Optional[Array]`

Sets the SMTP protocol extensions list that is passed to the client in
response to the EHLO command.

Default value: ``undef``

##### <a name="proxy_pass_error_message"></a>`proxy_pass_error_message`

Data type: `String`

Indicates whether to pass the error message obtained during the
authentication on the backend to the client.

Default value: `'off'`

##### <a name="server_name"></a>`server_name`

Data type: `Array`

List of mailhostnames for which this mailhost will respond.

Default value: `[$name]`

##### <a name="raw_prepend"></a>`raw_prepend`

Data type: `Optional[Variant[Array, String]]`

A single string, or an array of strings to prepend to the server directive
(after mailhost_cfg_prepend directive). NOTE: YOU are responsible for a
semicolon on each line that requires one.

Default value: ``undef``

##### <a name="raw_append"></a>`raw_append`

Data type: `Optional[Variant[Array, String]]`

A single string, or an array of strings to append to the server directive
(after mailhost_cfg_append directive). NOTE: YOU are responsible for a
semicolon on each line that requires one.

Default value: ``undef``

##### <a name="mailhost_cfg_append"></a>`mailhost_cfg_append`

Data type: `Optional[Hash]`

It expects a hash with custom directives to put after everything else
inside server

Default value: ``undef``

##### <a name="mailhost_cfg_prepend"></a>`mailhost_cfg_prepend`

Data type: `Optional[Hash]`

It expects a hash with custom directives to put before everything else
inside server

Default value: ``undef``

##### <a name="auth_http_header"></a>`auth_http_header`

Data type: `Optional[String]`



Default value: ``undef``

### <a name="nginxresourcemap"></a>`nginx::resource::map`

Create a new mapping entry for NGINX

#### Examples

##### 

```puppet
nginx::resource::map { 'backend_pool':
  ensure    => present,
  hostnames => true,
  default   => 'ny-pool-1,
  string    => '$http_host',
  mappings  => {
    '*.nyc.example.com' => 'ny-pool-1',
    '*.sf.example.com'  => 'sf-pool-1',
  }
}
```

##### Preserving input of order of mappings

```puppet
nginx::resource::map { 'backend_pool':
  ...
  mappings  => [
    { 'key' => '*.sf.example.com', 'value' => 'sf-pool-1' },
    { 'key' => '*.nyc.example.com', 'value' => 'ny-pool-1' },
  ]
}
```

##### Using external include

```puppet
nginx::resource::map { 'redirections':
   include_files => [ '/etc/nginx/conf.d/redirections.map']
}
```

##### Hiera usage

```puppet
nginx::string_mappings:
  client_network:
    ensure: present
    hostnames: true
    default: 'ny-pool-1'
    string: $http_host
    mappings:
      '*.nyc.example.com': 'ny-pool-1'
      '*.sf.example.com': 'sf-pool-1'
```

##### Hiera usage: preserving input of order of mappings:

```puppet
nginx::string_mappings:
  client_network:
    ...
    mappings:
      - key: '*.sf.example.com'
        value: 'sf-pool-1'
      - key: '*.nyc.example.com'
        value: 'ny-pool-1'
```

#### Parameters

The following parameters are available in the `nginx::resource::map` defined type:

* [`ensure`](#ensure)
* [`default`](#default)
* [`string`](#string)
* [`mappings`](#mappings)
* [`hostnames`](#hostnames)
* [`include_files`](#include_files)
* [`context`](#context)

##### <a name="ensure"></a>`ensure`

Data type: `Enum['absent', 'present']`

Enables or disables the specified location

Default value: `'present'`

##### <a name="default"></a>`default`

Data type: `Optional[String]`

Sets the resulting value if the source values fails to match any of the
variants.

Default value: ``undef``

##### <a name="string"></a>`string`

Data type: `String[2]`

Source string or variable to provide mapping for

##### <a name="mappings"></a>`mappings`

Data type: `Variant[Array, Hash]`

Hash of map lookup keys and resultant values

##### <a name="hostnames"></a>`hostnames`

Data type: `Boolean`

Indicates that source values can be hostnames with a prefix or suffix mask.

Default value: ``false``

##### <a name="include_files"></a>`include_files`

Data type: `Array[String]`

An array of external files to include

Default value: `[]`

##### <a name="context"></a>`context`

Data type: `Enum['http', 'stream']`

Specify if mapping is for http or stream context

Default value: `'http'`

### <a name="nginxresourceserver"></a>`nginx::resource::server`

Create a virtual host

#### Examples

##### 

```puppet
nginx::resource::server { 'test2.local':
  ensure   => present,
  www_root => '/var/www/nginx-default',
  ssl      => true,
  ssl_cert => '/tmp/server.crt',
  ssl_key  => '/tmp/server.pem',
}
```

#### Parameters

The following parameters are available in the `nginx::resource::server` defined type:

* [`ensure`](#ensure)
* [`listen_ip`](#listen_ip)
* [`listen_port`](#listen_port)
* [`listen_options`](#listen_options)
* [`listen_unix_socket_enable`](#listen_unix_socket_enable)
* [`listen_unix_socket`](#listen_unix_socket)
* [`listen_unix_socket_options`](#listen_unix_socket_options)
* [`location_satisfy`](#location_satisfy)
* [`location_allow`](#location_allow)
* [`location_deny`](#location_deny)
* [`ipv6_enable`](#ipv6_enable)
* [`ipv6_listen_ip`](#ipv6_listen_ip)
* [`ipv6_listen_port`](#ipv6_listen_port)
* [`ipv6_listen_options`](#ipv6_listen_options)
* [`add_header`](#add_header)
* [`index_files`](#index_files)
* [`autoindex`](#autoindex)
* [`autoindex_exact_size`](#autoindex_exact_size)
* [`autoindex_format`](#autoindex_format)
* [`autoindex_localtime`](#autoindex_localtime)
* [`reset_timedout_connection`](#reset_timedout_connection)
* [`proxy`](#proxy)
* [`proxy_read_timeout`](#proxy_read_timeout)
* [`proxy_send_timeout`](#proxy_send_timeout)
* [`proxy_redirect`](#proxy_redirect)
* [`proxy_buffering`](#proxy_buffering)
* [`proxy_request_buffering`](#proxy_request_buffering)
* [`proxy_max_temp_file_size`](#proxy_max_temp_file_size)
* [`proxy_busy_buffers_size`](#proxy_busy_buffers_size)
* [`resolver`](#resolver)
* [`fastcgi`](#fastcgi)
* [`fastcgi_param`](#fastcgi_param)
* [`fastcgi_params`](#fastcgi_params)
* [`fastcgi_index`](#fastcgi_index)
* [`fastcgi_script`](#fastcgi_script)
* [`uwsgi_read_timeout`](#uwsgi_read_timeout)
* [`ssl`](#ssl)
* [`ssl_cert`](#ssl_cert)
* [`ssl_client_cert`](#ssl_client_cert)
* [`ssl_verify_client`](#ssl_verify_client)
* [`ssl_crl`](#ssl_crl)
* [`ssl_dhparam`](#ssl_dhparam)
* [`ssl_ecdh_curve`](#ssl_ecdh_curve)
* [`ssl_prefer_server_ciphers`](#ssl_prefer_server_ciphers)
* [`ssl_redirect`](#ssl_redirect)
* [`ssl_redirect_port`](#ssl_redirect_port)
* [`ssl_key`](#ssl_key)
* [`ssl_port`](#ssl_port)
* [`ssl_protocols`](#ssl_protocols)
* [`ssl_buffer_size`](#ssl_buffer_size)
* [`ssl_ciphers`](#ssl_ciphers)
* [`ssl_stapling`](#ssl_stapling)
* [`ssl_stapling_file`](#ssl_stapling_file)
* [`ssl_stapling_responder`](#ssl_stapling_responder)
* [`ssl_stapling_verify`](#ssl_stapling_verify)
* [`ssl_session_timeout`](#ssl_session_timeout)
* [`ssl_session_tickets`](#ssl_session_tickets)
* [`ssl_session_ticket_key`](#ssl_session_ticket_key)
* [`ssl_trusted_cert`](#ssl_trusted_cert)
* [`ssl_verify_depth`](#ssl_verify_depth)
* [`ssl_password_file`](#ssl_password_file)
* [`spdy`](#spdy)
* [`http2`](#http2)
* [`server_name`](#server_name)
* [`www_root`](#www_root)
* [`rewrite_www_to_non_www`](#rewrite_www_to_non_www)
* [`rewrite_non_www_to_www`](#rewrite_non_www_to_www)
* [`try_files`](#try_files)
* [`proxy_cache`](#proxy_cache)
* [`proxy_cache_key`](#proxy_cache_key)
* [`proxy_cache_use_stale`](#proxy_cache_use_stale)
* [`proxy_cache_valid`](#proxy_cache_valid)
* [`proxy_cache_lock`](#proxy_cache_lock)
* [`proxy_cache_bypass`](#proxy_cache_bypass)
* [`proxy_method`](#proxy_method)
* [`proxy_http_version`](#proxy_http_version)
* [`proxy_set_body`](#proxy_set_body)
* [`absolute_redirect`](#absolute_redirect)
* [`auth_basic`](#auth_basic)
* [`auth_basic_user_file`](#auth_basic_user_file)
* [`auth_request`](#auth_request)
* [`client_max_body_size`](#client_max_body_size)
* [`client_body_timeout`](#client_body_timeout)
* [`client_header_timeout`](#client_header_timeout)
* [`raw_prepend`](#raw_prepend)
* [`raw_append`](#raw_append)
* [`location_raw_prepend`](#location_raw_prepend)
* [`location_raw_append`](#location_raw_append)
* [`server_cfg_append`](#server_cfg_append)
* [`server_cfg_prepend`](#server_cfg_prepend)
* [`server_cfg_ssl_append`](#server_cfg_ssl_append)
* [`server_cfg_ssl_prepend`](#server_cfg_ssl_prepend)
* [`include_files`](#include_files)
* [`access_log`](#access_log)
* [`error_log`](#error_log)
* [`passenger_cgi_param`](#passenger_cgi_param)
* [`passenger_set_header`](#passenger_set_header)
* [`passenger_env_var`](#passenger_env_var)
* [`passenger_pre_start`](#passenger_pre_start)
* [`log_by_lua`](#log_by_lua)
* [`log_by_lua_file`](#log_by_lua_file)
* [`gzip_types`](#gzip_types)
* [`gzip_static`](#gzip_static)
* [`owner`](#owner)
* [`group`](#group)
* [`mode`](#mode)
* [`maintenance`](#maintenance)
* [`maintenance_value`](#maintenance_value)
* [`error_pages`](#error_pages)
* [`locations`](#locations)
* [`locations_defaults`](#locations_defaults)
* [`ssl_listen_option`](#ssl_listen_option)
* [`ssl_cache`](#ssl_cache)
* [`proxy_connect_timeout`](#proxy_connect_timeout)
* [`proxy_set_header`](#proxy_set_header)
* [`proxy_hide_header`](#proxy_hide_header)
* [`proxy_pass_header`](#proxy_pass_header)
* [`uwsgi`](#uwsgi)
* [`uwsgi_params`](#uwsgi_params)
* [`location_custom_cfg`](#location_custom_cfg)
* [`location_cfg_prepend`](#location_cfg_prepend)
* [`location_cfg_append`](#location_cfg_append)
* [`location_custom_cfg_prepend`](#location_custom_cfg_prepend)
* [`location_custom_cfg_append`](#location_custom_cfg_append)
* [`format_log`](#format_log)
* [`use_default_location`](#use_default_location)
* [`rewrite_rules`](#rewrite_rules)
* [`string_mappings`](#string_mappings)
* [`geo_mappings`](#geo_mappings)

##### <a name="ensure"></a>`ensure`

Data type: `Enum['absent', 'present']`

Enables or disables the specified server

Default value: `'present'`

##### <a name="listen_ip"></a>`listen_ip`

Data type: `Variant[Array, String]`

Default IP Address for NGINX to listen with this server on. Defaults to all
interfaces (*)

Default value: `'*'`

##### <a name="listen_port"></a>`listen_port`

Data type: `Stdlib::Port`

Default TCP Port for NGINX to listen with this server on.

Default value: `80`

##### <a name="listen_options"></a>`listen_options`

Data type: `Optional[String]`

Extra options for listen directive like 'default_server' to catchall.

Default value: ``undef``

##### <a name="listen_unix_socket_enable"></a>`listen_unix_socket_enable`

Data type: `Boolean`

value to enable/disable UNIX socket listening support.

Default value: ``false``

##### <a name="listen_unix_socket"></a>`listen_unix_socket`

Data type: `Variant[Array[Stdlib::Absolutepath], Stdlib::Absolutepath]`

Default unix socket for NGINX to listen with this server on.

Default value: `'/var/run/nginx.sock'`

##### <a name="listen_unix_socket_options"></a>`listen_unix_socket_options`

Data type: `Optional[String]`

Extra options for listen directive like 'default' to catchall.

Default value: ``undef``

##### <a name="location_satisfy"></a>`location_satisfy`

Data type: `Optional[Enum['any', 'all']]`

Allows access if all (all) or at least one (any) of the auth modules allow
access.

Default value: ``undef``

##### <a name="location_allow"></a>`location_allow`

Data type: `Array`

Locations to allow connections from.

Default value: `[]`

##### <a name="location_deny"></a>`location_deny`

Data type: `Array`

Locations to deny connections from.

Default value: `[]`

##### <a name="ipv6_enable"></a>`ipv6_enable`

Data type: `Boolean`

value to enable/disable IPv6 support (false|true). Module will check to see
if IPv6 support exists on your system before enabling.

Default value: ``false``

##### <a name="ipv6_listen_ip"></a>`ipv6_listen_ip`

Data type: `Variant[Array, String]`

Default IPv6 Address for NGINX to listen with this server on. Defaults to all interfaces (::)

Default value: `'::'`

##### <a name="ipv6_listen_port"></a>`ipv6_listen_port`

Data type: `Stdlib::Port`

Default IPv6 Port for NGINX to listen with this server on. Defaults to TCP 80

Default value: `$listen_port`

##### <a name="ipv6_listen_options"></a>`ipv6_listen_options`

Data type: `String`

Extra options for listen directive like 'default' to catchall. Template
will allways add ipv6only=on.  While issue jfryman/puppet-nginx#30 is
discussed, default value is 'default'.

Default value: `'default ipv6only=on'`

##### <a name="add_header"></a>`add_header`

Data type: `Hash`

Adds headers to the HTTP response when response code is equal to 200, 204,
301, 302 or 304.

Default value: `{}`

##### <a name="index_files"></a>`index_files`

Data type: `Array`

Default index files for NGINX to read when traversing a directory

Default value: `[
    'index.html',
    'index.htm',
    'index.php',
  ]`

##### <a name="autoindex"></a>`autoindex`

Data type: `Optional[String]`

Set it on 'on' or 'off 'to activate/deactivate autoindex directory listing.

Default value: ``undef``

##### <a name="autoindex_exact_size"></a>`autoindex_exact_size`

Data type: `Optional[Enum['on', 'off']]`

Set it on 'on' or 'off' to activate/deactivate autoindex displaying exact
filesize, or rounded to kilobytes, megabytes and gigabytes.

Default value: ``undef``

##### <a name="autoindex_format"></a>`autoindex_format`

Data type: `Optional[Enum['html', 'xml', 'json', 'jsonp']]`

Sets the format of a directory listing.

Default value: ``undef``

##### <a name="autoindex_localtime"></a>`autoindex_localtime`

Data type: `Optional[Enum['on', 'off']]`

Specifies whether times in the directory listing should be output in the
local time zone or UTC.

Default value: ``undef``

##### <a name="reset_timedout_connection"></a>`reset_timedout_connection`

Data type: `Optional[Enum['on', 'off']]`

Enables or disables resetting timed out connections and connections closed
with the non-standard code 444.

Default value: ``undef``

##### <a name="proxy"></a>`proxy`

Data type: `Optional[String]`

Proxy server(s) for the root location to connect to. Accepts a single
value, can be used in conjunction with nginx::resource::upstream

Default value: ``undef``

##### <a name="proxy_read_timeout"></a>`proxy_read_timeout`

Data type: `String`

Override the default proxy read timeout value of 90 seconds

Default value: `$nginx::proxy_read_timeout`

##### <a name="proxy_send_timeout"></a>`proxy_send_timeout`

Data type: `String`

Override the default proxy send timeout value of 90 seconds

Default value: `$nginx::proxy_send_timeout`

##### <a name="proxy_redirect"></a>`proxy_redirect`

Data type: `Optional[String]`

Override the default proxy_redirect value of off.

Default value: ``undef``

##### <a name="proxy_buffering"></a>`proxy_buffering`

Data type: `Optional[String]`

If defined, sets the proxy_buffering to the passed value.

Default value: ``undef``

##### <a name="proxy_request_buffering"></a>`proxy_request_buffering`

Data type: `Optional[String]`

If defined, sets the proxy_request_buffering to the passed value.

Default value: ``undef``

##### <a name="proxy_max_temp_file_size"></a>`proxy_max_temp_file_size`

Data type: `Optional[Nginx::Size]`

Sets the maximum size of the temporary buffer file.

Default value: ``undef``

##### <a name="proxy_busy_buffers_size"></a>`proxy_busy_buffers_size`

Data type: `Optional[Nginx::Size]`

Sets the total size of buffers that can be busy sending a response to the
client while the response is not yet fully read.

Default value: ``undef``

##### <a name="resolver"></a>`resolver`

Data type: `Array`

Configures name servers used to resolve names of upstream servers into addresses.

Default value: `[]`

##### <a name="fastcgi"></a>`fastcgi`

Data type: `Optional[String]`

location of fastcgi (host:port)

Default value: ``undef``

##### <a name="fastcgi_param"></a>`fastcgi_param`

Data type: `Any`

Set additional custom fastcgi_params

Default value: ``undef``

##### <a name="fastcgi_params"></a>`fastcgi_params`

Data type: `String`

optional alternative fastcgi_params file to use

Default value: `"${nginx::conf_dir}/fastcgi.conf"`

##### <a name="fastcgi_index"></a>`fastcgi_index`

Data type: `Optional[String]`

optional FastCGI index page

Default value: ``undef``

##### <a name="fastcgi_script"></a>`fastcgi_script`

Data type: `Optional[String]`

optional SCRIPT_FILE parameter

Default value: ``undef``

##### <a name="uwsgi_read_timeout"></a>`uwsgi_read_timeout`

Data type: `Optional[String]`

optional value for uwsgi_read_timeout

Default value: ``undef``

##### <a name="ssl"></a>`ssl`

Data type: `Boolean`

Indicates whether to setup SSL bindings for this server.

Default value: ``false``

##### <a name="ssl_cert"></a>`ssl_cert`

Data type: `Optional[Variant[String, Boolean, Array[String]]]`

Pre-generated SSL Certificate file to reference for SSL Support. This is
not generated by this module.  Set to `false` to inherit from the http
section, which improves performance by conserving memory.
Use an array to add multiple SSL Certificates.

Default value: ``undef``

##### <a name="ssl_client_cert"></a>`ssl_client_cert`

Data type: `Optional[String]`

Pre-generated SSL Certificate file to reference for client verify SSL
Support. This is not generated by this module.

Default value: ``undef``

##### <a name="ssl_verify_client"></a>`ssl_verify_client`

Data type: `String`

Enables verification of client certificates.

Default value: `'on'`

##### <a name="ssl_crl"></a>`ssl_crl`

Data type: `Optional[String]`

Specifies CRL path in file system

Default value: ``undef``

##### <a name="ssl_dhparam"></a>`ssl_dhparam`

Data type: `Optional[String]`

This directive specifies a file containing Diffie-Hellman key agreement
protocol cryptographic parameters, in PEM format, utilized for exchanging
session keys between server and client.

Default value: ``undef``

##### <a name="ssl_ecdh_curve"></a>`ssl_ecdh_curve`

Data type: `Optional[String]`

This directive specifies a curve for ECDHE ciphers.

Default value: ``undef``

##### <a name="ssl_prefer_server_ciphers"></a>`ssl_prefer_server_ciphers`

Data type: `Optional[Enum['on', 'off']]`

String: Specifies that server ciphers should be preferred over client
ciphers when using the SSLv3 and TLS protocols.

Default value: ``undef``

##### <a name="ssl_redirect"></a>`ssl_redirect`

Data type: `Boolean`

Adds a server directive and return statement to force ssl redirect. Will
honor ssl_port if it's set.

Default value: ``false``

##### <a name="ssl_redirect_port"></a>`ssl_redirect_port`

Data type: `Optional[Integer]`

Overrides $ssl_port in the SSL redirect set by ssl_redirect

Default value: ``undef``

##### <a name="ssl_key"></a>`ssl_key`

Data type: `Optional[Variant[String, Boolean, Array[String]]]`

Pre-generated SSL Key file to reference for SSL Support. This is not
generated by this module. Set to `false` to inherit from the http section,
which improves performance by conserving memory.
Use an array to add multiple SSL Keys.

Default value: ``undef``

##### <a name="ssl_port"></a>`ssl_port`

Data type: `Integer`

Default IP Port for NGINX to listen with this SSL server on.

Default value: `443`

##### <a name="ssl_protocols"></a>`ssl_protocols`

Data type: `Optional[String]`

SSL protocols enabled. Defaults to 'TLSv1 TLSv1.1 TLSv1.2'.

Default value: ``undef``

##### <a name="ssl_buffer_size"></a>`ssl_buffer_size`

Data type: `Optional[String]`

Sets the size of the buffer used for sending data.

Default value: ``undef``

##### <a name="ssl_ciphers"></a>`ssl_ciphers`

Data type: `Optional[String]`

SSL ciphers enabled.

Default value: ``undef``

##### <a name="ssl_stapling"></a>`ssl_stapling`

Data type: `Boolean`

Enables or disables stapling of OCSP responses by the server.

Default value: ``false``

##### <a name="ssl_stapling_file"></a>`ssl_stapling_file`

Data type: `Optional[String]`

When set, the stapled OCSP response will be taken from the specified file
instead of querying the OCSP responder specified in the server certificate.

Default value: ``undef``

##### <a name="ssl_stapling_responder"></a>`ssl_stapling_responder`

Data type: `Optional[String]`

Overrides the URL of the OCSP responder specified in the Authority
Information Access certificate extension.

Default value: ``undef``

##### <a name="ssl_stapling_verify"></a>`ssl_stapling_verify`

Data type: `Boolean`

Enables or disables verification of OCSP responses by the server. Defaults to false.

Default value: ``false``

##### <a name="ssl_session_timeout"></a>`ssl_session_timeout`

Data type: `Optional[String]`

Specifies a time during which a client may reuse the session parameters stored in a cache.
  Defaults to 5m.

Default value: ``undef``

##### <a name="ssl_session_tickets"></a>`ssl_session_tickets`

Data type: `Optional[Enum['on', 'off']]`

Enables or disables session resumption through TLS session tickets.

Default value: ``undef``

##### <a name="ssl_session_ticket_key"></a>`ssl_session_ticket_key`

Data type: `Optional[String]`

Sets a file with the secret key used to encrypt and decrypt TLS session tickets.

Default value: ``undef``

##### <a name="ssl_trusted_cert"></a>`ssl_trusted_cert`

Data type: `Optional[String]`

Specifies a file with trusted CA certificates in the PEM format used to verify client
  certificates and OCSP responses if ssl_stapling is enabled.

Default value: ``undef``

##### <a name="ssl_verify_depth"></a>`ssl_verify_depth`

Data type: `Optional[Integer]`

Sets the verification depth in the client certificates chain.

Default value: ``undef``

##### <a name="ssl_password_file"></a>`ssl_password_file`

Data type: `Optional[Stdlib::Absolutepath]`

File containing the password for the SSL Key file.

Default value: ``undef``

##### <a name="spdy"></a>`spdy`

Data type: `Enum['on', 'off']`

Toggles SPDY protocol.

Default value: `$nginx::spdy`

##### <a name="http2"></a>`http2`

Data type: `Enum['on', 'off']`

Toggles HTTP/2 protocol.

Default value: `$nginx::http2`

##### <a name="server_name"></a>`server_name`

Data type: `Array[String]`

List of servernames for which this server will respond. Default [$name].

Default value: `[$name]`

##### <a name="www_root"></a>`www_root`

Data type: `Optional[String]`

Specifies the location on disk for files to be read from. Cannot be set in conjunction with $proxy

Default value: ``undef``

##### <a name="rewrite_www_to_non_www"></a>`rewrite_www_to_non_www`

Data type: `Boolean`

Adds a server directive and rewrite rule to rewrite www.domain.com to domain.com in order to avoid
  duplicate content (SEO);

Default value: ``false``

##### <a name="rewrite_non_www_to_www"></a>`rewrite_non_www_to_www`

Data type: `Boolean`

Adds a server directive and rewrite rule to rewrite domain.com to www.domain.com in order to avoid
  duplicate content (SEO);

Default value: ``false``

##### <a name="try_files"></a>`try_files`

Data type: `Optional[Array[String]]`

Specifies the locations for files to be checked as an array. Cannot be used in conjuction with $proxy.

Default value: ``undef``

##### <a name="proxy_cache"></a>`proxy_cache`

Data type: `Optional[String]`

This directive sets name of zone for caching. The same zone can be used in multiple places.

Default value: ``undef``

##### <a name="proxy_cache_key"></a>`proxy_cache_key`

Data type: `Optional[String]`

Override the default proxy_cache_key of $scheme$proxy_host$request_uri

Default value: ``undef``

##### <a name="proxy_cache_use_stale"></a>`proxy_cache_use_stale`

Data type: `Optional[String]`

Override the default proxy_cache_use_stale value of off.

Default value: ``undef``

##### <a name="proxy_cache_valid"></a>`proxy_cache_valid`

Data type: `Optional[Variant[Array[String], String]]`

This directive sets the time for caching different replies.

Default value: ``undef``

##### <a name="proxy_cache_lock"></a>`proxy_cache_lock`

Data type: `Optional[Enum['on', 'off']]`

This directive sets the locking mechanism for pouplating cache.

Default value: ``undef``

##### <a name="proxy_cache_bypass"></a>`proxy_cache_bypass`

Data type: `Optional[Variant[Array[String], String]]`

Defines conditions which the response will not be cached

Default value: ``undef``

##### <a name="proxy_method"></a>`proxy_method`

Data type: `Optional[String]`

If defined, overrides the HTTP method of the request to be passed to the backend.

Default value: ``undef``

##### <a name="proxy_http_version"></a>`proxy_http_version`

Data type: `Optional[String]`

Sets the proxy http version

Default value: ``undef``

##### <a name="proxy_set_body"></a>`proxy_set_body`

Data type: `Optional[String]`

If defined, sets the body passed to the backend.

Default value: ``undef``

##### <a name="absolute_redirect"></a>`absolute_redirect`

Data type: `Optional[Enum['on', 'off']]`

Enables or disables the absolute redirect functionality of nginx

Default value: ``undef``

##### <a name="auth_basic"></a>`auth_basic`

Data type: `Optional[String]`

This directive includes testing name and password with HTTP Basic Authentication.

Default value: ``undef``

##### <a name="auth_basic_user_file"></a>`auth_basic_user_file`

Data type: `Optional[String]`

This directive sets the htpasswd filename for the authentication realm.

Default value: ``undef``

##### <a name="auth_request"></a>`auth_request`

Data type: `Optional[String]`

This allows you to specify a custom auth endpoint

Default value: ``undef``

##### <a name="client_max_body_size"></a>`client_max_body_size`

Data type: `Any`

This directive sets client_max_body_size.

Default value: ``undef``

##### <a name="client_body_timeout"></a>`client_body_timeout`

Data type: `Optional[String]`

Sets how long the server will wait for a client body. Default is 60s

Default value: ``undef``

##### <a name="client_header_timeout"></a>`client_header_timeout`

Data type: `Optional[String]`

Sets how long the server will wait for a client header. Default is 60s

Default value: ``undef``

##### <a name="raw_prepend"></a>`raw_prepend`

Data type: `Optional[Variant[Array[String], String]]`

A single string, or an array of strings to prepend to the server directive
(after cfg prepend directives). NOTE: YOU are responsible for a semicolon
on each line that requires one.

Default value: ``undef``

##### <a name="raw_append"></a>`raw_append`

Data type: `Optional[Variant[Array[String], String]]`

A single string, or an array of strings to append to the server directive
(after cfg append directives). NOTE: YOU are responsible for a semicolon on
each line that requires one.

Default value: ``undef``

##### <a name="location_raw_prepend"></a>`location_raw_prepend`

Data type: `Optional[Variant[Array[String], String]]`

A single string, or an array of strings to prepend to the location
directive (after custom_cfg directives). NOTE: YOU are responsible for a
semicolon on each line that requires one.

Default value: ``undef``

##### <a name="location_raw_append"></a>`location_raw_append`

Data type: `Optional[Variant[Array[String], String]]`

A single string, or an array of strings to append to the location directive
(after custom_cfg directives). NOTE: YOU are responsible for a semicolon on
each line that requires one.

Default value: ``undef``

##### <a name="server_cfg_append"></a>`server_cfg_append`

Data type: `Optional[Hash]`

It expects a hash with custom directives to put after everything else inside server

Default value: ``undef``

##### <a name="server_cfg_prepend"></a>`server_cfg_prepend`

Data type: `Optional[Hash]`

It expects a hash with custom directives to put before everything else inside server

Default value: ``undef``

##### <a name="server_cfg_ssl_append"></a>`server_cfg_ssl_append`

Data type: `Optional[Hash]`

It expects a hash with custom directives to put after everything else inside server ssl

Default value: ``undef``

##### <a name="server_cfg_ssl_prepend"></a>`server_cfg_ssl_prepend`

Data type: `Optional[Hash]`

It expects a hash with custom directives to put before everything else inside server ssl

Default value: ``undef``

##### <a name="include_files"></a>`include_files`

Data type: `Optional[Array[String]]`

Adds include files to server

Default value: ``undef``

##### <a name="access_log"></a>`access_log`

Data type: `Optional[Variant[String, Array]]`

Where to write access log (log format can be set with $format_log). This
can be either a string or an array; in the latter case, multiple lines will
be created. Additionally, unlike the earlier behavior, setting it to
'absent' in the server context will remove this directive entirely from the
server stanza, rather than setting a default. Can also be disabled for this
server with the string 'off'.

Default value: ``undef``

##### <a name="error_log"></a>`error_log`

Data type: `Optional[Variant[String, Array]]`

Where to write error log. May add additional options like error level to
the end. May set to 'absent', in which case it will be omitted in this
server stanza (and default to nginx.conf setting)

Default value: ``undef``

##### <a name="passenger_cgi_param"></a>`passenger_cgi_param`

Data type: `Optional[Hash]`

Allows one to define additional CGI environment variables to pass to the backend application

Default value: ``undef``

##### <a name="passenger_set_header"></a>`passenger_set_header`

Data type: `Optional[Hash]`

Allows one to set headers to pass to the backend application (Passenger 5.0+)

Default value: ``undef``

##### <a name="passenger_env_var"></a>`passenger_env_var`

Data type: `Optional[Hash]`

Allows one to set environment variables to pass to the backend application (Passenger 5.0+)

Default value: ``undef``

##### <a name="passenger_pre_start"></a>`passenger_pre_start`

Data type: `Optional[Variant[Array[String], String]]`

Allows setting a URL to pre-warm the host. Per Passenger docs, the "domain
part of the URL" must match a value of server_name. If this is an array,
multiple URLs can be specified.

Default value: ``undef``

##### <a name="log_by_lua"></a>`log_by_lua`

Data type: `Optional[String]`

Run the Lua source code inlined as the <lua-script-str> at the log request
processing phase. This does not replace the current access logs, but runs
after.

Default value: ``undef``

##### <a name="log_by_lua_file"></a>`log_by_lua_file`

Data type: `Optional[String]`

Equivalent to log_by_lua, except that the file specified by
<path-to-lua-script-file> contains the Lua code, or, as from the v0.5.0rc32
release, the Lua/LuaJIT bytecode to be executed.

Default value: ``undef``

##### <a name="gzip_types"></a>`gzip_types`

Data type: `Optional[String]`

Defines gzip_types, nginx default is text/html

Default value: ``undef``

##### <a name="gzip_static"></a>`gzip_static`

Data type: `Optional[String]`

Defines gzip_static, nginx default is off

Default value: ``undef``

##### <a name="owner"></a>`owner`

Data type: `String`

Defines owner of the .conf file

Default value: `$nginx::global_owner`

##### <a name="group"></a>`group`

Data type: `String`

Defines group of the .conf file

Default value: `$nginx::global_group`

##### <a name="mode"></a>`mode`

Data type: `String`

Defines mode of the .conf file

Default value: `$nginx::global_mode`

##### <a name="maintenance"></a>`maintenance`

Data type: `Boolean`

A boolean value to set a server in maintenance

Default value: ``false``

##### <a name="maintenance_value"></a>`maintenance_value`

Data type: `String`

Value to return when maintenance is on.

Default value: `'return 503'`

##### <a name="error_pages"></a>`error_pages`

Data type: `Any`

Setup errors pages, hash key is the http code and hash value the page

Default value: ``undef``

##### <a name="locations"></a>`locations`

Data type: `Hash`

Hash of location resources used by this server

Default value: `{}`

##### <a name="locations_defaults"></a>`locations_defaults`

Data type: `Hash`

Hash of location default settings

Default value: `{}`

##### <a name="ssl_listen_option"></a>`ssl_listen_option`

Data type: `Boolean`



Default value: ``true``

##### <a name="ssl_cache"></a>`ssl_cache`

Data type: `Optional[String]`



Default value: ``undef``

##### <a name="proxy_connect_timeout"></a>`proxy_connect_timeout`

Data type: `Any`



Default value: `$nginx::proxy_connect_timeout`

##### <a name="proxy_set_header"></a>`proxy_set_header`

Data type: `Array[String]`



Default value: `$nginx::proxy_set_header`

##### <a name="proxy_hide_header"></a>`proxy_hide_header`

Data type: `Array[String]`



Default value: `$nginx::proxy_hide_header`

##### <a name="proxy_pass_header"></a>`proxy_pass_header`

Data type: `Array[String]`



Default value: `$nginx::proxy_pass_header`

##### <a name="uwsgi"></a>`uwsgi`

Data type: `Optional[String]`



Default value: ``undef``

##### <a name="uwsgi_params"></a>`uwsgi_params`

Data type: `String`



Default value: `"${nginx::config::conf_dir}/uwsgi_params"`

##### <a name="location_custom_cfg"></a>`location_custom_cfg`

Data type: `Optional[Hash]`



Default value: ``undef``

##### <a name="location_cfg_prepend"></a>`location_cfg_prepend`

Data type: `Optional[Hash]`



Default value: ``undef``

##### <a name="location_cfg_append"></a>`location_cfg_append`

Data type: `Optional[Hash]`



Default value: ``undef``

##### <a name="location_custom_cfg_prepend"></a>`location_custom_cfg_prepend`

Data type: `Optional[Hash]`



Default value: ``undef``

##### <a name="location_custom_cfg_append"></a>`location_custom_cfg_append`

Data type: `Optional[Hash]`



Default value: ``undef``

##### <a name="format_log"></a>`format_log`

Data type: `Optional[String]`



Default value: `$nginx::http_format_log`

##### <a name="use_default_location"></a>`use_default_location`

Data type: `Any`



Default value: ``true``

##### <a name="rewrite_rules"></a>`rewrite_rules`

Data type: `Any`



Default value: `[]`

##### <a name="string_mappings"></a>`string_mappings`

Data type: `Any`



Default value: `{}`

##### <a name="geo_mappings"></a>`geo_mappings`

Data type: `Any`



Default value: `{}`

### <a name="nginxresourcesnippet"></a>`nginx::resource::snippet`

Create a reusable config snippet that can be included by other resources

#### Parameters

The following parameters are available in the `nginx::resource::snippet` defined type:

* [`ensure`](#ensure)
* [`owner`](#owner)
* [`group`](#group)
* [`mode`](#mode)
* [`raw_content`](#raw_content)

##### <a name="ensure"></a>`ensure`

Data type: `Enum['absent', 'present']`

Enables or disables the specified snippet

Default value: `'present'`

##### <a name="owner"></a>`owner`

Data type: `String`

Defines owner of the .conf file

Default value: `$nginx::global_owner`

##### <a name="group"></a>`group`

Data type: `String`

Defines group of the .conf file

Default value: `$nginx::global_group`

##### <a name="mode"></a>`mode`

Data type: `Stdlib::Filemode`

Defines mode of the .conf file

Default value: `$nginx::global_mode`

##### <a name="raw_content"></a>`raw_content`

Data type: `String[1]`

Raw content that will be inserted into the snipped as-is

### <a name="nginxresourcestreamhost"></a>`nginx::resource::streamhost`

Create a virtual steamhost

#### Examples

##### 

```puppet
nginx::resource::streamhost { 'test2.local':
  ensure   => present,
}
```

#### Parameters

The following parameters are available in the `nginx::resource::streamhost` defined type:

* [`ensure`](#ensure)
* [`listen_ip`](#listen_ip)
* [`listen_port`](#listen_port)
* [`listen_options`](#listen_options)
* [`ipv6_enable`](#ipv6_enable)
* [`ipv6_listen_ip`](#ipv6_listen_ip)
* [`ipv6_listen_port`](#ipv6_listen_port)
* [`ipv6_listen_options`](#ipv6_listen_options)
* [`proxy`](#proxy)
* [`proxy_read_timeout`](#proxy_read_timeout)
* [`resolver`](#resolver)
* [`raw_prepend`](#raw_prepend)
* [`raw_append`](#raw_append)
* [`owner`](#owner)
* [`group`](#group)
* [`mode`](#mode)
* [`proxy_connect_timeout`](#proxy_connect_timeout)

##### <a name="ensure"></a>`ensure`

Data type: `Enum['absent', 'present']`

Enables or disables the specified streamhost

Default value: `'present'`

##### <a name="listen_ip"></a>`listen_ip`

Data type: `Variant[Array, String]`

Default IP Address for NGINX to listen with this streamhost on. Defaults to
all interfaces (*)

Default value: `'*'`

##### <a name="listen_port"></a>`listen_port`

Data type: `Integer`

Default TCP Port for NGINX to listen with this streamhost on.

Default value: `80`

##### <a name="listen_options"></a>`listen_options`

Data type: `Optional[String]`

Extra options for listen directive like 'default' to catchall.

Default value: ``undef``

##### <a name="ipv6_enable"></a>`ipv6_enable`

Data type: `Boolean`

Value to enable/disable IPv6 support Module will check to see if IPv6
support exists on your system before enabling.

Default value: ``false``

##### <a name="ipv6_listen_ip"></a>`ipv6_listen_ip`

Data type: `Variant[Array, String]`

Default IPv6 Address for NGINX to listen with this streamhost on. Defaults
to all interfaces (::)

Default value: `'::'`

##### <a name="ipv6_listen_port"></a>`ipv6_listen_port`

Data type: `Integer`

Default IPv6 Port for NGINX to listen with this streamhost on.

Default value: `$listen_port`

##### <a name="ipv6_listen_options"></a>`ipv6_listen_options`

Data type: `String`

Extra options for listen directive like 'default' to catchall. Template
will allways add ipv6only=on. While issue jfryman/puppet-nginx#30 is
discussed, default value is 'default'.

Default value: `'default ipv6only=on'`

##### <a name="proxy"></a>`proxy`

Data type: `Any`

Proxy server(s) for the root location to connect to. Accepts a single
value, can be used in conjunction with nginx::resource::upstream

Default value: ``undef``

##### <a name="proxy_read_timeout"></a>`proxy_read_timeout`

Data type: `String`

Override the default the proxy read timeout value of 90 seconds

Default value: `$nginx::proxy_read_timeout`

##### <a name="resolver"></a>`resolver`

Data type: `Array`

Configures name servers used to resolve names of upstream servers into
addresses.

Default value: `[]`

##### <a name="raw_prepend"></a>`raw_prepend`

Data type: `Variant[Array[String], String]`

A single string, or an array of strings to prepend to the server directive
(after cfg prepend directives). NOTE: YOU are responsible for a semicolon
on each line that requires one.

Default value: `[]`

##### <a name="raw_append"></a>`raw_append`

Data type: `Variant[Array[String], String]`

A single string, or an array of strings to append to the server directive
(after cfg append directives). NOTE: YOU are responsible for a semicolon on
each line that requires one.

Default value: `[]`

##### <a name="owner"></a>`owner`

Data type: `String`

Defines owner of the .conf file

Default value: `$nginx::global_owner`

##### <a name="group"></a>`group`

Data type: `String`

Defines group of the .conf file

Default value: `$nginx::global_group`

##### <a name="mode"></a>`mode`

Data type: `String`

Defines mode of the .conf file Default to return 503

Default value: `$nginx::global_mode`

##### <a name="proxy_connect_timeout"></a>`proxy_connect_timeout`

Data type: `Any`



Default value: `$nginx::proxy_connect_timeout`

### <a name="nginxresourceupstream"></a>`nginx::resource::upstream`

Create a new upstream proxy entry for NGINX

#### Examples

##### 

```puppet
nginx::resource::upstream { 'proxypass':
  ensure  => present,
  members => {
    'localhost:3001' => {
      server => 'localhost',
      port   => 3001,
    },
    'localhost:3002' => {
      server => 'localhost',
      port   => 3002,
    },
    'localhost:3003' => {
      server => 'localhost',
      port   => 3003,
    },
  },
}
```

##### Custom config example to use ip_hash, and 20 keepalive connections create a hash with any extra custom config you want.

```puppet
nginx::resource::upstream { 'proxypass':
  ensure    => present,
  members   => {
    'localhost:3001' => {
      server => 'localhost',
      port   => 3001,
    },
    'localhost:3002' => {
      server => 'localhost',
      port   => 3002,
    },
    'localhost:3003' => {
      server => 'localhost',
      port   => 3003,
    },
  },
  ip_hash   => true,
  keepalive => 20,
}
```

#### Parameters

The following parameters are available in the `nginx::resource::upstream` defined type:

* [`ensure`](#ensure)
* [`context`](#context)
* [`members`](#members)
* [`members_tag`](#members_tag)
* [`member_defaults`](#member_defaults)
* [`hash`](#hash)
* [`ip_hash`](#ip_hash)
* [`keepalive`](#keepalive)
* [`keepalive_requests`](#keepalive_requests)
* [`keepalive_timeout`](#keepalive_timeout)
* [`least_conn`](#least_conn)
* [`least_time`](#least_time)
* [`ntlm`](#ntlm)
* [`queue_max`](#queue_max)
* [`queue_timeout`](#queue_timeout)
* [`random`](#random)
* [`statefile`](#statefile)
* [`sticky`](#sticky)
* [`zone`](#zone)
* [`cfg_append`](#cfg_append)
* [`cfg_prepend`](#cfg_prepend)

##### <a name="ensure"></a>`ensure`

Data type: `Enum['present', 'absent']`

Enables or disables the specified location

Default value: `'present'`

##### <a name="context"></a>`context`

Data type: `Enum['http', 'stream']`

Set the type of this upstream.

Default value: `'http'`

##### <a name="members"></a>`members`

Data type: `Nginx::UpstreamMembers`

Hash of member URIs for NGINX to connect to. Must follow valid NGINX
syntax.  If omitted, individual members should be defined with
nginx::resource::upstream::member

Default value: `{}`

##### <a name="members_tag"></a>`members_tag`

Data type: `Optional[String[1]]`

Restrict collecting the exported members for this upstream with a tag.

Default value: ``undef``

##### <a name="member_defaults"></a>`member_defaults`

Data type: `Nginx::UpstreamMemberDefaults`

Specify default settings added to each member of this upstream.

Default value: `{}`

##### <a name="hash"></a>`hash`

Data type: `Optional[String[1]]`

Activate the hash load balancing method
(https://nginx.org/en/docs/http/ngx_http_upstream_module.html#hash).

Default value: ``undef``

##### <a name="ip_hash"></a>`ip_hash`

Data type: `Boolean`

Activate ip_hash for this upstream
(https://nginx.org/en/docs/http/ngx_http_upstream_module.html#ip_hash).

Default value: ``false``

##### <a name="keepalive"></a>`keepalive`

Data type: `Optional[Integer[1]]`

Set the maximum number of idle keepalive connections
(https://nginx.org/en/docs/http/ngx_http_upstream_module.html#keepalive).

Default value: ``undef``

##### <a name="keepalive_requests"></a>`keepalive_requests`

Data type: `Optional[Integer[1]]`

Sets the maximum number of requests that can be served through one
keepalive connection
(https://nginx.org/en/docs/http/ngx_http_upstream_module.html#keepalive_requests).

Default value: ``undef``

##### <a name="keepalive_timeout"></a>`keepalive_timeout`

Data type: `Optional[Nginx::Time]`

Sets a timeout during which an idle keepalive connection to an upstream
server will stay open
(https://nginx.org/en/docs/http/ngx_http_upstream_module.html#keepalive_timeout).

Default value: ``undef``

##### <a name="least_conn"></a>`least_conn`

Data type: `Boolean`

Activate the least_conn load balancing method
(https://nginx.org/en/docs/http/ngx_http_upstream_module.html#least_conn).

Default value: ``false``

##### <a name="least_time"></a>`least_time`

Data type: `Optional[Nginx::UpstreamLeastTime]`

Activate the least_time load balancing method
(https://nginx.org/en/docs/http/ngx_http_upstream_module.html#least_time).

Default value: ``undef``

##### <a name="ntlm"></a>`ntlm`

Data type: `Boolean`

Allow NTLM authentication
(https://nginx.org/en/docs/http/ngx_http_upstream_module.html#ntlm).

Default value: ``false``

##### <a name="queue_max"></a>`queue_max`

Data type: `Optional[Integer]`

Set the maximum number of queued requests
(https://nginx.org/en/docs/http/ngx_http_upstream_module.html#queue).

Default value: ``undef``

##### <a name="queue_timeout"></a>`queue_timeout`

Data type: `Optional[Nginx::Time]`

Set the timeout for the queue
(https://nginx.org/en/docs/http/ngx_http_upstream_module.html#queue).

Default value: ``undef``

##### <a name="random"></a>`random`

Data type: `Optional[String[1]]`

Activate the random load balancing method
(https://nginx.org/en/docs/http/ngx_http_upstream_module.html#random).

Default value: ``undef``

##### <a name="statefile"></a>`statefile`

Data type: `Optional[Stdlib::Unixpath]`

Specifies a file that keeps the state of the dynamically configurable group
(https://nginx.org/en/docs/http/ngx_http_upstream_module.html#state).

Default value: ``undef``

##### <a name="sticky"></a>`sticky`

Data type: `Optional[Nginx::UpstreamSticky]`

Enables session affinity
(https://nginx.org/en/docs/http/ngx_http_upstream_module.html#sticky).

Default value: ``undef``

##### <a name="zone"></a>`zone`

Data type: `Optional[Nginx::UpstreamZone]`

Defines the name and optional the size of the shared memory zone
(https://nginx.org/en/docs/http/ngx_http_upstream_module.html#zone).

Default value: ``undef``

##### <a name="cfg_append"></a>`cfg_append`

Data type: `Nginx::UpstreamCustomParameters`

Hash of custom directives to put after other directives in upstream

Default value: `{}`

##### <a name="cfg_prepend"></a>`cfg_prepend`

Data type: `Nginx::UpstreamCustomParameters`

It expects a hash with custom directives to put before anything else inside
upstream

Default value: `{}`

### <a name="nginxresourceupstreammember"></a>`nginx::resource::upstream::member`

Export this resource in all upstream member servers and collect them on the
NGINX server. Exporting resources requires storeconfigs on the Puppetserver
to export and collect resources

#### Examples

##### Exporting the resource on a upstream member server:

```puppet
@@nginx::resource::upstream::member { $trusted['certname']:
  ensure   => present,
  upstream => 'proxypass',
  server   => $facts['networking']['ip'],
  port     => 3000,
}
```

##### Collecting the resource on the NGINX server:

```puppet
nginx::resource::upstream { 'proxypass':
  ensure => present,
}
```

#### Parameters

The following parameters are available in the `nginx::resource::upstream::member` defined type:

* [`upstream`](#upstream)
* [`ensure`](#ensure)
* [`context`](#context)
* [`server`](#server)
* [`port`](#port)
* [`weight`](#weight)
* [`max_conns`](#max_conns)
* [`max_fails`](#max_fails)
* [`fail_timeout`](#fail_timeout)
* [`backup`](#backup)
* [`resolve`](#resolve)
* [`route`](#route)
* [`service`](#service)
* [`slow_start`](#slow_start)
* [`state`](#state)
* [`params_prepend`](#params_prepend)
* [`params_append`](#params_append)
* [`comment`](#comment)

##### <a name="upstream"></a>`upstream`

Data type: `String[1]`

The name of the upstream resource

##### <a name="ensure"></a>`ensure`

Data type: `Enum['present', 'absent']`

Enables or disables the specified member

Default value: `'present'`

##### <a name="context"></a>`context`

Data type: `Enum['http', 'stream']`

Set the type of this upstream

Default value: `'http'`

##### <a name="server"></a>`server`

Data type: `Optional[Nginx::UpstreamMemberServer]`

Hostname or IP of the upstream member server

Default value: `$name`

##### <a name="port"></a>`port`

Data type: `Stdlib::Port`

Port of the listening service on the upstream member

Default value: `80`

##### <a name="weight"></a>`weight`

Data type: `Optional[Integer[1]]`

Set the weight for this upstream member

Default value: ``undef``

##### <a name="max_conns"></a>`max_conns`

Data type: `Optional[Integer[1]]`

Set the max_conns for this upstream member

Default value: ``undef``

##### <a name="max_fails"></a>`max_fails`

Data type: `Optional[Integer[0]]`

Set the max_fails for this upstream member

Default value: ``undef``

##### <a name="fail_timeout"></a>`fail_timeout`

Data type: `Optional[Nginx::Time]`

Set the fail_timeout for this upstream member

Default value: ``undef``

##### <a name="backup"></a>`backup`

Data type: `Boolean`

Activate backup for this upstream member

Default value: ``false``

##### <a name="resolve"></a>`resolve`

Data type: `Boolean`

Activate resolve for this upstream member

Default value: ``false``

##### <a name="route"></a>`route`

Data type: `Optional[String[1]]`

Set the route for this upstream member

Default value: ``undef``

##### <a name="service"></a>`service`

Data type: `Optional[String[1]]`

Set the service for this upstream member

Default value: ``undef``

##### <a name="slow_start"></a>`slow_start`

Data type: `Optional[Nginx::Time]`

Set the slow_start for this upstream member

Default value: ``undef``

##### <a name="state"></a>`state`

Data type: `Optional[Enum['drain','down']]`

Set the state for this upstream member

Default value: ``undef``

##### <a name="params_prepend"></a>`params_prepend`

Data type: `Optional[String[1]]`

prepend a parameter for this upstream member

Default value: ``undef``

##### <a name="params_append"></a>`params_append`

Data type: `Optional[String[1]]`

append a paremeter for this upstream member

Default value: ``undef``

##### <a name="comment"></a>`comment`

Data type: `Optional[String[1]]`

Add a comment for this upstream member

Default value: ``undef``

## Data types

### <a name="nginxdebugconnection"></a>`Nginx::DebugConnection`

The Nginx::DebugConnection data type.

Alias of

```puppet
Variant[Stdlib::Host, Stdlib::IP::Address, Enum['unix:']]
```

### <a name="nginxerrorlogseverity"></a>`Nginx::ErrorLogSeverity`

The Nginx::ErrorLogSeverity data type.

Alias of

```puppet
Enum['debug', 'info', 'notice', 'warn', 'error', 'crit', 'alert', 'emerg']
```

### <a name="nginxsize"></a>`Nginx::Size`

The Nginx::Size data type.

Alias of

```puppet
Pattern[/^\d+[k|K|m|M]?$/]
```

### <a name="nginxtime"></a>`Nginx::Time`

The Nginx::Time data type.

Alias of

```puppet
Pattern[/^\d+(ms|s|m|h|d|w|M|y)?$/]
```

### <a name="nginxupstreamcustomparameters"></a>`Nginx::UpstreamCustomParameters`

The Nginx::UpstreamCustomParameters data type.

Alias of

```puppet
Hash[String[1], Variant[
    String[1],
    Integer,
    Array[
      Variant[
        String[1],
        Integer
      ]
    ],
    Hash[String[1],
      Variant[
        String[1],
        Integer,
        Array[
          Variant[
            String[1],
            Integer,
          ]
        ]
      ]
    ]
  ]]
```

### <a name="nginxupstreamdefaults"></a>`Nginx::UpstreamDefaults`

The Nginx::UpstreamDefaults data type.

Alias of

```puppet
Struct[{
  context           => Optional[Enum['http', 'stream']],
  member_defaults   => Optional[Nginx::UpstreamMemberDefaults],
  hash              => Optional[String],
  ip_hash           => Optional[Boolean],
  keepalive         => Optional[Integer[1]],
  kepalive_requests => Optional[Integer[1]],
  keepalive_timeout => Optional[Nginx::Time],
  least_conn        => Optional[Boolean],
  least_time        => Optional[Nginx::UpstreamLeastTime],
  ntlm              => Optional[Boolean],
  queue_max         => Optional[Integer],
  queue_timeout     => Optional[Nginx::Time],
  random            => Optional[String],
  statefile         => Optional[Stdlib::Unixpath],
  sticky            => Optional[Nginx::UpstreamSticky],
  zone              => Optional[Nginx::UpstreamZone],
  cfg_append        => Optional[Hash],
  cfg_prepend       => Optional[Hash],
}]
```

### <a name="nginxupstreamleasttime"></a>`Nginx::UpstreamLeastTime`

The Nginx::UpstreamLeastTime data type.

Alias of

```puppet
Variant[Nginx::UpstreamLeastTimeHttp, Nginx::UpstreamLeastTimeStream]
```

### <a name="nginxupstreamleasttimehttp"></a>`Nginx::UpstreamLeastTimeHttp`

The Nginx::UpstreamLeastTimeHttp data type.

Alias of

```puppet
Enum['header', 'header inflight', 'last_byte', 'last_byte inflight']
```

### <a name="nginxupstreamleasttimestream"></a>`Nginx::UpstreamLeastTimeStream`

The Nginx::UpstreamLeastTimeStream data type.

Alias of

```puppet
Enum['connect', 'connect inflight', 'first_byte', 'first_byte inflight', 'last_byte', 'last_byte inflight']
```

### <a name="nginxupstreammember"></a>`Nginx::UpstreamMember`

The Nginx::UpstreamMember data type.

Alias of

```puppet
Struct[{
  server         => Optional[Nginx::UpstreamMemberServer],
  port           => Optional[Stdlib::Port],
  weight         => Optional[Integer[1]],
  max_conns      => Optional[Integer[1]],
  max_fails      => Optional[Integer[0]],
  fail_timeout   => Optional[Nginx::Time],
  backup         => Optional[Boolean],
  resolve        => Optional[Boolean],
  route          => Optional[String],
  service        => Optional[String],
  slow_start     => Optional[Nginx::Time],
  state          => Optional[Enum['drain','down']],
  params_prepend => Optional[String],
  params_append  => Optional[String],
  comment        => Optional[String],
}]
```

### <a name="nginxupstreammemberdefaults"></a>`Nginx::UpstreamMemberDefaults`

The Nginx::UpstreamMemberDefaults data type.

Alias of

```puppet
Struct[{
  server         => Optional[Nginx::UpstreamMemberServer],
  port           => Optional[Stdlib::Port],
  weight         => Optional[Integer[1]],
  max_conns      => Optional[Integer[1]],
  max_fails      => Optional[Integer[0]],
  fail_timeout   => Optional[Nginx::Time],
  backup         => Optional[Boolean],
  resolve        => Optional[Boolean],
  route          => Optional[String],
  service        => Optional[String],
  slow_start     => Optional[Nginx::Time],
  state          => Optional[Enum['drain','down']],
  params_prepend => Optional[String],
  params_append  => Optional[String],
}]
```

### <a name="nginxupstreammemberserver"></a>`Nginx::UpstreamMemberServer`

The Nginx::UpstreamMemberServer data type.

Alias of

```puppet
Variant[Stdlib::Host, Pattern[/^unix:\/([^\/\0]+\/*)[^:]*$/]]
```

### <a name="nginxupstreammembers"></a>`Nginx::UpstreamMembers`

The Nginx::UpstreamMembers data type.

Alias of

```puppet
Hash[String, Nginx::UpstreamMember]
```

### <a name="nginxupstreamsticky"></a>`Nginx::UpstreamSticky`

The Nginx::UpstreamSticky data type.

Alias of

```puppet
Variant[Hash[
    Enum['cookie'],
    Struct[{
      name     => String,
      expires  => Optional[Variant[Nginx::Time,Enum['max']]],
      domain   => Optional[String],
      httponly => Optional[Boolean],
      secure   => Optional[Boolean],
      path     => Optional[String],
    }]
  ], Hash[
    Enum['route'],
    String
  ], Hash[
    Enum['learn'],
    Struct[{
      create  => String,
      lookup  => String,
      zone    => Nginx::UpstreamStickyZone,
      timeout => Optional[Nginx::Time],
      header  => Optional[Boolean],
      sync    => Optional[Boolean],
    }]
  ]]
```

### <a name="nginxupstreamstickyzone"></a>`Nginx::UpstreamStickyZone`

The Nginx::UpstreamStickyZone data type.

Alias of

```puppet
Pattern[/^[-_\.A-Za-z0-9]*:\d+[k|K|m|M]$/]
```

### <a name="nginxupstreamzone"></a>`Nginx::UpstreamZone`

The Nginx::UpstreamZone data type.

Alias of

```puppet
Pattern[/^[-_\.A-Za-z0-9]* \d+[k|K|m|M]$/]
```

